/*
 *******************************************************************************
 *
 *  Copyright 2020 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author RIEGL LMS GmbH, Austria
 * \brief  Description of RIEGL RDB 2 database file contents
 *
 *  NOTE: All information in this file is preliminary, since the
 *        definition of the database schemas is not yet complete.
 *
 *******************************************************************************
 */

#ifndef RDB_6DC7FF98_C890_4397_90B3_45A2547A201F
#define RDB_6DC7FF98_C890_4397_90B3_45A2547A201F

#include <vector>
#include <string>

namespace riegl {
namespace rdb {
namespace pointcloud {

// File schema version
const std::string RDB_SCHEMA_VERSION = "ab4e0cc0";
const std::string RDB_SCHEMA_DATE = "2021-05-03";

// Schema for ".avg.fwa" files
const std::string RDB_SCHEMA_RIEGL_AVG_FWA(
    "{\"extension\":\"avg.fwa\",\"attributes\":[\"riegl.id*\",\"riegl.amplitude\",\"ri"
    "egl.gain\",\"riegl.raw_range\",\"riegl.wfm_echo_time_offset\",\"riegl.wfm_sb"
    "l_id\",\"riegl.deviation?\",\"riegl.pulse_width?\"],\"identifier\":\"avg.fwa\","
    "\"metadata\":[]}"
);

// Schema for ".avg.sbx" files
const std::string RDB_SCHEMA_RIEGL_AVG_SBX(
    "{\"extension\":\"avg.sbx\",\"attributes\":[\"riegl.id*\",\"riegl.wfm_sbl_channe"
    "l\",\"riegl.wfm_sbl_mean\",\"riegl.wfm_sbl_std_dev\",\"riegl.wfm_sbl_time_of"
    "fset\",\"riegl.wfm_sda_first\",\"riegl.wfm_sda_count\"],\"identifier\":\"avg.s"
    "bx\",\"metadata\":[]}"
);

// Schema for ".avg.sidx" files
const std::string RDB_SCHEMA_RIEGL_AVG_SIDX(
    "{\"extension\":\"avg.sidx\",\"attributes\":[\"riegl.id\",\"riegl.shot_timestamp"
    "_hr*\",\"riegl.wfm_sbl_first\",\"riegl.wfm_sbl_count\",\"riegl.echo_first?\","
    "\"riegl.echo_count?\"],\"identifier\":\"avg.sidx\",\"metadata\":[\"riegl.shot_i"
    "nfo\",\"riegl.waveform_info\",\"riegl.echo_info?\",\"riegl.waveform_averagin"
    "g_settings\"]}"
);

// Schema for ".avg.sp{C}" files
const std::string RDB_SCHEMA_RIEGL_AVG_SPC(
    "{\"extension\":\"avg.sp{C}\",\"attributes\":[\"riegl.id*\",\"riegl.wfm_sample_v"
    "alue\"],\"identifier\":\"avg.sp{C}\",\"metadata\":[]}"
);

// Schema for ".cpx" files
const std::string RDB_SCHEMA_RIEGL_CPX(
    "{\"extension\":\"cpx\",\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.xyz_ac"
    "curacies\",\"riegl.control_object_type\",\"riegl.zenith_vector\",\"riegl.use"
    "d_for_adjustment\",\"riegl.acquisition_date?\",\"riegl.cp_surface_inclinat"
    "ion_angle\",\"riegl.cp_surface_inclination_tolerance_angle\",\"riegl.impor"
    "t_line_number\"],\"identifier\":\"cpx\",\"metadata\":[\"riegl.geo_tag\",\"riegl."
    "control_object_catalog\",\"riegl.record_names\",\"riegl.imported_files\"]}"
);

// Schema for ".fwa" files
const std::string RDB_SCHEMA_RIEGL_FWA(
    "{\"extension\":\"fwa\",\"attributes\":[\"riegl.id*\",\"riegl.amplitude\",\"riegl."
    "gain\",\"riegl.raw_range\",\"riegl.wfm_echo_time_offset\",\"riegl.wfm_sbl_id"
    "\",\"riegl.deviation?\",\"riegl.pulse_width?\"],\"identifier\":\"fwa\",\"metadat"
    "a\":[]}"
);

// Schema for ".mpx" files
const std::string RDB_SCHEMA_RIEGL_MPX(
    "{\"extension\":\"mpx\",\"attributes\":[\"riegl.id\",\"riegl.xy_map*\",\"riegl.amp"
    "litude\",\"riegl.reflectance\",\"riegl.deviation\",\"riegl.timestamp_min?\",\""
    "riegl.timestamp_max?\",\"riegl.point_count\",\"riegl.point_count_grid_cell"
    "\",\"riegl.pixel_linear_sums?\",\"riegl.pixel_square_sums?\",\"riegl.height_"
    "min\",\"riegl.height_max\",\"riegl.height_mean\",\"riegl.height_center\",\"rie"
    "gl.surface_normal\",\"riegl.pca_thickness\",\"riegl.std_dev\",\"riegl.voxel_"
    "count\"],\"identifier\":\"mpx\",\"metadata\":[\"riegl.geo_tag\",\"riegl.pixel_in"
    "fo\",\"riegl.time_base?\"]}"
);

// Schema for ".mtch" files
const std::string RDB_SCHEMA_RIEGL_MTCH(
    "{\"extension\":\"mtch\",\"attributes\":[\"riegl.xyz*\",\"riegl.plane_references"
    "\",\"riegl.plane_patch_distance\",\"riegl.plane_patch_lateral_distance\",\"r"
    "iegl.plane_patch_link_vector\",\"riegl.id\"],\"identifier\":\"mtch\",\"metadat"
    "a\":[\"riegl.plane_patch_matching\"]}"
);

// Schema for ".mvx" files
const std::string RDB_SCHEMA_RIEGL_MVX(
    "{\"extension\":\"mvx\",\"attributes\":[\"riegl.id\",\"riegl.xyz_map*\",\"riegl.am"
    "plitude\",\"riegl.reflectance\",\"riegl.deviation\",\"riegl.timestamp_min?\","
    "\"riegl.timestamp_max?\",\"riegl.point_count\",\"riegl.shape_id\",\"riegl.cov"
    "ariances?\",\"riegl.pca_axis_min\",\"riegl.pca_axis_max\",\"riegl.pca_extent"
    "s\",\"riegl.std_dev\",\"riegl.voxel_collapsed\"],\"identifier\":\"mvx\",\"metada"
    "ta\":[\"riegl.geo_tag\",\"riegl.time_base?\",\"riegl.voxel_info\"]}"
);

// Schema for ".obsx" files
const std::string RDB_SCHEMA_RIEGL_OBSX(
    "{\"extension\":\"obsx\",\"attributes\":[\"riegl.xyz\",\"riegl.surface_normal\",\""
    "riegl.plane_slope_class?\",\"riegl.id*\",\"riegl.sda1_plane_patch_one\",\"ri"
    "egl.sda1_plane_patch_two\",\"riegl.sda1_source_file_one\",\"riegl.sda1_sou"
    "rce_file_two\"],\"identifier\":\"obsx\",\"metadata\":[\"riegl.geo_tag\",\"riegl."
    "plane_slope_class_info?\",\"riegl.pointcloud_info\",\"riegl.sda1_source_fi"
    "les\"]}"
);

// Schema for ".opefx" files
const std::string RDB_SCHEMA_RIEGL_OPEFX(
    "{\"extension\":\"opefx\",\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.xyz_"
    "accuracies?\",\"riegl.surface_normal\",\"riegl.plane_up\",\"riegl.point_coun"
    "t\",\"riegl.std_dev\",\"riegl.plane_width\",\"riegl.plane_height\",\"riegl.pla"
    "ne_confidence_normal\",\"riegl.model_fit_quality?\",\"riegl.used_for_adjus"
    "tment\",\"riegl.xyz_socs\",\"riegl.timestamp\",\"riegl.mirror_facet\",\"riegl."
    "platform_rpy_ROCS_NED\",\"riegl.platform_drpy_ROCS_NED\",\"riegl.platform_"
    "xyz_ROCS_ENU\",\"riegl.platform_dxyz_ROCS_ENU\",\"riegl.sda.shift_vector\","
    "\"riegl.raw_range\",\"riegl.raw_frame_angle\",\"riegl.raw_line_angle\",\"rieg"
    "l.reference_object_id\"],\"identifier\":\"opefx\",\"metadata\":[\"riegl.device"
    "\",\"riegl.device_geometry\",\"riegl.geo_tag\",\"riegl.georeferencing_parame"
    "ters\",\"riegl.scan_pattern?\",\"riegl.time_base\",\"riegl.record_names\",\"ri"
    "egl.control_object_reference_file\"]}"
);

// Schema for ".opp" files
const std::string RDB_SCHEMA_RIEGL_OPP(
    "{\"extension\":\"opp\",\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.xyz_ac"
    "curacies?\",\"riegl.surface_normal\",\"riegl.plane_up\",\"riegl.point_count\""
    ",\"riegl.std_dev\",\"riegl.plane_width\",\"riegl.plane_height\",\"riegl.plane"
    "_confidence_normal\",\"riegl.model_fit_quality?\",\"riegl.used_for_adjustm"
    "ent\",\"riegl.xyz_socs\",\"riegl.timestamp\",\"riegl.mirror_facet\",\"riegl.pl"
    "atform_rpy_ROCS_NED\",\"riegl.platform_drpy_ROCS_NED\",\"riegl.platform_xy"
    "z_ROCS_ENU\",\"riegl.platform_dxyz_ROCS_ENU\",\"riegl.sda.shift_vector\",\"r"
    "iegl.raw_range\",\"riegl.raw_frame_angle\",\"riegl.raw_line_angle\",\"riegl."
    "reference_object_id\"],\"identifier\":\"opp\",\"metadata\":[\"riegl.device\",\"r"
    "iegl.device_geometry\",\"riegl.geo_tag\",\"riegl.georeferencing_parameters"
    "\",\"riegl.scan_pattern?\",\"riegl.time_base\",\"riegl.record_names\",\"riegl."
    "control_object_reference_file\"]}"
);

// Schema for ".opx" files
const std::string RDB_SCHEMA_RIEGL_OPX(
    "{\"extension\":\"opx\",\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.contro"
    "l_object_type\",\"riegl.model_cs_axis_x?\",\"riegl.model_cs_axis_y?\",\"rieg"
    "l.model_cs_axis_z?\",\"riegl.model_fit_quality?\",\"riegl.obs_confidence_x"
    "y?\",\"riegl.obs_confidence_z?\",\"riegl.obs_signal_confidence_rot?\",\"rieg"
    "l.used_for_adjustment\",\"riegl.xyz_socs\",\"riegl.timestamp\",\"riegl.mirro"
    "r_facet\",\"riegl.platform_rpy_ROCS_NED\",\"riegl.platform_drpy_ROCS_NED\","
    "\"riegl.platform_xyz_ROCS_ENU\",\"riegl.platform_dxyz_ROCS_ENU\",\"riegl.sd"
    "a.shift_vector\",\"riegl.raw_range\",\"riegl.raw_frame_angle\",\"riegl.raw_l"
    "ine_angle\",\"riegl.reference_object_id\"],\"identifier\":\"opx\",\"metadata\":"
    "[\"riegl.device\",\"riegl.device_geometry\",\"riegl.geo_tag\",\"riegl.georefe"
    "rencing_parameters\",\"riegl.scan_pattern?\",\"riegl.time_base\",\"riegl.con"
    "trol_object_catalog\",\"riegl.record_names\",\"riegl.control_object_refere"
    "nce_file\"]}"
);

// Schema for ".owp" files
const std::string RDB_SCHEMA_RIEGL_OWP(
    "{\"extension\":\"owp\",\"attributes\":[\"riegl.id*\",\"riegl.raw_range\",\"riegl."
    "amplitude\",\"riegl.deviation\",\"riegl.gain\"],\"identifier\":\"owp\",\"metadat"
    "a\":[]}"
);

// Schema for ".pefx" files
const std::string RDB_SCHEMA_RIEGL_PEFX(
    "{\"extension\":\"pefx\",\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.xyz_a"
    "ccuracies?\",\"riegl.surface_normal\",\"riegl.plane_up\",\"riegl.std_dev\",\"r"
    "iegl.plane_confidence_normal\",\"riegl.plane_width\",\"riegl.plane_height\""
    ",\"riegl.vertex_first\",\"riegl.vertex_count\",\"riegl.used_for_adjustment\""
    ",\"riegl.acquisition_date?\",\"riegl.import_line_number\",\"riegl.import_li"
    "ne_count\"],\"identifier\":\"pefx\",\"metadata\":[\"riegl.geo_tag\",\"riegl.vert"
    "ex_info\",\"riegl.record_names\",\"riegl.imported_files\"]}"
);

// Schema for ".pofx" files
const std::string RDB_SCHEMA_RIEGL_PROJECT_POFX(
    "{\"extension\":\"pofx\",\"attributes\":[\"riegl.id\",\"riegl.pof_timestamp*\",\"r"
    "iegl.pof_latitude\",\"riegl.pof_longitude\",\"riegl.pof_height\",\"riegl.pof"
    "_roll\",\"riegl.pof_pitch\",\"riegl.pof_yaw\",\"riegl.pof_path_length\"],\"ide"
    "ntifier\":\"project.pofx\",\"metadata\":[\"riegl.time_base\",\"riegl.trajector"
    "y_info\"]}"
);

// Schema for ".pofx" files
const std::string RDB_SCHEMA_RIEGL_SCAN_POFX(
    "{\"extension\":\"pofx\",\"attributes\":[\"riegl.id\",\"riegl.pof_timestamp*\",\"r"
    "iegl.pof_latitude\",\"riegl.pof_longitude\",\"riegl.pof_height\",\"riegl.pof"
    "_roll\",\"riegl.pof_pitch\",\"riegl.pof_yaw\",\"riegl.pof_path_length\",\"rieg"
    "l.pof_xyz\",\"riegl.pof_roll_ned\",\"riegl.pof_pitch_ned\",\"riegl.pof_yaw_n"
    "ed\"],\"identifier\":\"scan.pofx\",\"metadata\":[\"riegl.time_base\",\"riegl.geo"
    "_tag\",\"riegl.trajectory_info\"]}"
);

// Schema for ".poqx" files
const std::string RDB_SCHEMA_RIEGL_PROJECT_POQX(
    "{\"extension\":\"poqx\",\"attributes\":[\"riegl.id\",\"riegl.pof_timestamp*\",\"r"
    "iegl.pof_accuracy_north\",\"riegl.pof_accuracy_east\",\"riegl.pof_accuracy"
    "_down\",\"riegl.pof_accuracy_roll\",\"riegl.pof_accuracy_pitch\",\"riegl.pof"
    "_accuracy_yaw\",\"riegl.pof_path_length\",\"riegl.pof_pdop\",\"riegl.pof_sat"
    "ellites_gnss?\",\"riegl.pof_satellites_gps?\",\"riegl.pof_satellites_glona"
    "ss?\",\"riegl.pof_satellites_beidou?\",\"riegl.pof_satellites_galileo?\",\"r"
    "iegl.pof_satellites_qzss?\"],\"identifier\":\"project.poqx\",\"metadata\":[\"r"
    "iegl.time_base\",\"riegl.trajectory_info\"]}"
);

// Schema for ".poqx" files
const std::string RDB_SCHEMA_RIEGL_SCAN_POQX(
    "{\"extension\":\"poqx\",\"attributes\":[\"riegl.id\",\"riegl.pof_timestamp*\",\"r"
    "iegl.pof_accuracy_north\",\"riegl.pof_accuracy_east\",\"riegl.pof_accuracy"
    "_down\",\"riegl.pof_accuracy_roll\",\"riegl.pof_accuracy_pitch\",\"riegl.pof"
    "_accuracy_yaw\",\"riegl.pof_path_length\",\"riegl.pof_pdop\",\"riegl.pof_sat"
    "ellites_gnss?\",\"riegl.pof_satellites_gps?\",\"riegl.pof_satellites_glona"
    "ss?\",\"riegl.pof_satellites_beidou?\",\"riegl.pof_satellites_galileo?\",\"r"
    "iegl.pof_satellites_qzss?\"],\"identifier\":\"scan.poqx\",\"metadata\":[\"rieg"
    "l.time_base\",\"riegl.trajectory_info\"]}"
);

// Schema for ".ppx" files
const std::string RDB_SCHEMA_RIEGL_PPX(
    "{\"extension\":\"ppx\",\"attributes\":[\"riegl.id\",\"riegl.pps_timestamp_inter"
    "n*\",\"riegl.pps_timestamp_extern\"],\"identifier\":\"ppx\",\"metadata\":[\"rieg"
    "l.device\",\"riegl.time_base\"]}"
);

// Schema for ".ptch" files
const std::string RDB_SCHEMA_RIEGL_PROJECT_PTCH(
    "{\"extension\":\"ptch\",\"attributes\":[\"riegl.xyz*\",\"riegl.surface_normal\","
    "\"riegl.plane_up\",\"riegl.reflectance?\",\"riegl.point_count\",\"riegl.std_d"
    "ev\",\"riegl.plane_width\",\"riegl.plane_height\",\"riegl.plane_count\",\"rieg"
    "l.covariances\",\"riegl.id\"],\"identifier\":\"project.ptch\",\"metadata\":[\"ri"
    "egl.device\",\"riegl.geo_tag?\",\"riegl.scan_pattern?\",\"riegl.time_base?\","
    "\"riegl.plane_patch_statistics?\"]}"
);

// Schema for ".ptch" files
const std::string RDB_SCHEMA_RIEGL_SCAN_PTCH(
    "{\"extension\":\"ptch\",\"attributes\":[\"riegl.xyz*\",\"riegl.xyz_socs\",\"riegl"
    ".direction?\",\"riegl.direction_medium?\",\"riegl.direction_coarse?\",\"rieg"
    "l.surface_normal\",\"riegl.plane_up\",\"riegl.timestamp\",\"riegl.reflectanc"
    "e?\",\"riegl.point_count\",\"riegl.std_dev\",\"riegl.plane_width\",\"riegl.pla"
    "ne_height\",\"riegl.plane_count\",\"riegl.mirror_facet\",\"riegl.covariances"
    "\",\"riegl.id\",\"riegl.plane_slope_class?\",\"riegl.plane_occupancy\",\"riegl"
    ".plane_confidence_normal\",\"riegl.plane_cog_link\",\"riegl.match_count\",\""
    "riegl.platform_rpy_ROCS_NED\",\"riegl.platform_xyz_ROCS_ENU\",\"riegl.plat"
    "form_drpy_ROCS_NED\",\"riegl.platform_dxyz_ROCS_ENU\",\"riegl.sda.shift_ve"
    "ctor\",\"riegl.raw_range\",\"riegl.raw_frame_angle\",\"riegl.raw_line_angle\""
    "],\"identifier\":\"scan.ptch\",\"metadata\":[\"riegl.device\",\"riegl.device_ge"
    "ometry\",\"riegl.geo_tag\",\"riegl.georeferencing_parameters\",\"riegl.scan_"
    "pattern?\",\"riegl.time_base\",\"riegl.plane_patch_statistics?\",\"riegl.pla"
    "ne_slope_class_info?\"]}"
);

// Schema for ".ptch" files
const std::string RDB_SCHEMA_RIEGL_SCANPOS_PTCH(
    "{\"extension\":\"ptch\",\"attributes\":[\"riegl.xyz*\",\"riegl.surface_normal\","
    "\"riegl.plane_up\",\"riegl.reflectance?\",\"riegl.point_count\",\"riegl.std_d"
    "ev\",\"riegl.plane_width\",\"riegl.plane_height\",\"riegl.plane_count\",\"rieg"
    "l.covariances\",\"riegl.id\"],\"identifier\":\"scanpos.ptch\",\"metadata\":[\"ri"
    "egl.device\",\"riegl.geo_tag?\",\"riegl.scan_pattern?\",\"riegl.time_base?\","
    "\"riegl.plane_patch_statistics?\"]}"
);

// Schema for ".rdbx" files
const std::string RDB_SCHEMA_RIEGL_RDBX(
    "{\"extension\":\"rdbx\",\"attributes\":[\"riegl.id\",\"riegl.timestamp\",\"riegl."
    "xyz*\",\"riegl.xyz_socs\",\"riegl.direction_medium\",\"riegl.amplitude\",\"rie"
    "gl.reflectance?\",\"riegl.deviation?\",\"riegl.pulse_width?\",\"riegl.target"
    "_index\",\"riegl.target_count\",\"riegl.mirror_facet?\",\"riegl.scan_segment"
    "?\",\"riegl.mta_unresolved?\",\"riegl.mta_zone?\",\"riegl.window_echo_impact"
    "_corrected?\",\"riegl.rgba?\",\"riegl.class?\",\"riegl.start_of_scan_line?\","
    "\"riegl.end_of_scan_line?\",\"riegl.source_indicator?\",\"riegl.fwa?\",\"rieg"
    "l.waveform_available?\",\"riegl.wfm_sbl_id?\",\"riegl.wfm_echo_time_offset"
    "?\",\"riegl.scan_angle\",\"riegl.scan_direction\",\"riegl.source_index?\",\"ri"
    "egl.hydro_intersection_point?\",\"riegl.hydro_intersection_normal?\"],\"id"
    "entifier\":\"rdbx\",\"metadata\":[\"riegl.atmosphere\",\"riegl.beam_geometry\","
    "\"riegl.device_geometry\",\"riegl.device\",\"riegl.gaussian_decomposition?\""
    ",\"riegl.exponential_decomposition?\",\"riegl.geo_tag\",\"riegl.georeferenc"
    "ing_parameters\",\"riegl.mta_settings?\",\"riegl.near_range_correction?\",\""
    "riegl.noise_estimates?\",\"riegl.angular_notch_filter?\",\"riegl.notch_fil"
    "ter?\",\"riegl.pointcloud_info?\",\"riegl.pulse_position_modulation?\",\"rie"
    "gl.range_statistics?\",\"riegl.receiver_internals?\",\"riegl.reflectance_c"
    "alculation?\",\"riegl.reflectance_correction?\",\"riegl.scan_pattern\",\"rie"
    "gl.time_base\",\"riegl.waveform_settings?\",\"riegl.window_analysis?\",\"rie"
    "gl.window_echo_correction?\"]}"
);

// Schema for ".rmvx" files
const std::string RDB_SCHEMA_RIEGL_RMVX(
    "{\"extension\":\"rmvx\",\"attributes\":[\"riegl.id\",\"riegl.voxel_index*\",\"rie"
    "gl.amplitude\",\"riegl.reflectance\",\"riegl.deviation\",\"riegl.direction_m"
    "edium\",\"riegl.point_count\",\"riegl.voxel_linear_sums\",\"riegl.voxel_squa"
    "re_sums\",\"riegl.timestamp_min?\",\"riegl.timestamp_max?\"],\"identifier\":\""
    "rmvx\",\"metadata\":[\"riegl.geo_tag\",\"riegl.voxel_info\",\"riegl.time_base?"
    "\"]}"
);

// Schema for ".s10x" files
const std::string RDB_SCHEMA_RIEGL_S10X(
    "{\"extension\":\"s10x\",\"attributes\":[\"riegl.id\",\"riegl.timestamp*\",\"riegl"
    ".frame_angle_coarse\",\"riegl.gyroscope_raw\",\"riegl.accelerometer_raw\",\""
    "riegl.magnetic_field_sensor_raw\",\"riegl.gyroscope\",\"riegl.acceleromete"
    "r\",\"riegl.magnetic_field_sensor\",\"riegl.barometric_height_amsl\",\"riegl"
    ".temperature\",\"riegl.line_scan_active\",\"riegl.frame_scan_active\",\"rieg"
    "l.data_acquisition_active\"],\"identifier\":\"s10x\",\"metadata\":[\"riegl.tim"
    "e_base\",\"riegl.pose_sensors\"]}"
);

// Schema for ".sbx" files
const std::string RDB_SCHEMA_RIEGL_SBX(
    "{\"extension\":\"sbx\",\"attributes\":[\"riegl.id*\",\"riegl.wfm_sbl_channel\",\""
    "riegl.wfm_sbl_mean\",\"riegl.wfm_sbl_std_dev\",\"riegl.wfm_sbl_time_offset"
    "\",\"riegl.wfm_sda_first\",\"riegl.wfm_sda_count\"],\"identifier\":\"sbx\",\"met"
    "adata\":[]}"
);

// Schema for ".sdcx" files
const std::string RDB_SCHEMA_RIEGL_SDCX(
    "{\"extension\":\"sdcx\",\"attributes\":[\"riegl.id\",\"riegl.timestamp*\",\"riegl"
    ".xyz\",\"riegl.amplitude\",\"riegl.reflectance?\",\"riegl.deviation?\",\"riegl"
    ".pulse_width?\",\"riegl.target_index\",\"riegl.target_count\",\"riegl.mirror"
    "_facet?\",\"riegl.scan_segment?\",\"riegl.mta_unresolved?\",\"riegl.mta_zone"
    "?\",\"riegl.window_echo_impact_corrected?\",\"riegl.class?\",\"riegl.start_o"
    "f_scan_line?\",\"riegl.end_of_scan_line?\",\"riegl.source_indicator?\",\"rie"
    "gl.fwa?\",\"riegl.waveform_available?\",\"riegl.wfm_sbl_id?\",\"riegl.wfm_ec"
    "ho_time_offset?\"],\"identifier\":\"sdcx\",\"metadata\":[\"riegl.atmosphere\",\""
    "riegl.beam_geometry\",\"riegl.device_geometry\",\"riegl.device\",\"riegl.gau"
    "ssian_decomposition?\",\"riegl.exponential_decomposition?\",\"riegl.mta_se"
    "ttings?\",\"riegl.near_range_correction?\",\"riegl.noise_estimates?\",\"rieg"
    "l.angular_notch_filter?\",\"riegl.notch_filter?\",\"riegl.pointcloud_info?"
    "\",\"riegl.pulse_position_modulation?\",\"riegl.range_statistics?\",\"riegl."
    "receiver_internals?\",\"riegl.reflectance_calculation?\",\"riegl.reflectan"
    "ce_correction?\",\"riegl.scan_pattern\",\"riegl.time_base\",\"riegl.window_a"
    "nalysis?\",\"riegl.window_echo_correction?\"]}"
);

// Schema for ".sidx" files
const std::string RDB_SCHEMA_RIEGL_SIDX(
    "{\"extension\":\"sidx\",\"attributes\":[\"riegl.id\",\"riegl.shot_timestamp_hr*"
    "\",\"riegl.echo_first\",\"riegl.echo_count\"],\"identifier\":\"sidx\",\"metadata"
    "\":[\"riegl.shot_info\",\"riegl.echo_info\"]}"
);

// Schema for ".sodx" files
const std::string RDB_SCHEMA_RIEGL_SODX(
    "{\"extension\":\"sodx\",\"attributes\":[\"riegl.id\",\"riegl.shot_timestamp_hr*"
    "\",\"riegl.mirror_facet\",\"riegl.scan_segment\",\"riegl.start_of_scan_line\""
    ",\"riegl.line_angle_coarse\",\"riegl.shot_origin\",\"riegl.shot_direction\","
    "\"riegl.shot_direction_levelled?\",\"riegl.wfm_sbl_first?\",\"riegl.wfm_sbl"
    "_count?\",\"riegl.echo_first?\",\"riegl.echo_count?\"],\"identifier\":\"sodx\","
    "\"metadata\":[\"riegl.atmosphere\",\"riegl.device\",\"riegl.device_geometry\","
    "\"riegl.device_output_limits\",\"riegl.beam_geometry\",\"riegl.near_range_c"
    "orrection?\",\"riegl.window_echo_correction?\",\"riegl.receiver_internals?"
    "\",\"riegl.gaussian_decomposition?\",\"riegl.exponential_decomposition?\",\""
    "riegl.mta_settings?\",\"riegl.pulse_position_modulation?\",\"riegl.notch_f"
    "ilter?\",\"riegl.reflectance_calculation?\",\"riegl.scan_pattern\",\"riegl.t"
    "ime_base\",\"riegl.waveform_info?\",\"riegl.echo_info?\"]}"
);

// Schema for ".sp{C}" files
const std::string RDB_SCHEMA_RIEGL_SPC(
    "{\"extension\":\"sp{C}\",\"attributes\":[\"riegl.id*\",\"riegl.wfm_sample_value"
    "\"],\"identifier\":\"sp{C}\",\"metadata\":[]}"
);

// Schema for ".vtx" files
const std::string RDB_SCHEMA_RIEGL_VTX(
    "{\"extension\":\"vtx\",\"attributes\":[\"riegl.id*\",\"riegl.xyz\",\"riegl.xyz_ac"
    "curacies?\"],\"identifier\":\"vtx\",\"metadata\":[\"riegl.geo_tag\"]}"
);

// Schema for ".vxls" files
const std::string RDB_SCHEMA_RIEGL_VXLS(
    "{\"extension\":\"vxls\",\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.covar"
    "iances\",\"riegl.pca_axis_max\",\"riegl.pca_axis_min\",\"riegl.pca_extents\","
    "\"riegl.point_count\",\"riegl.reflectance\",\"riegl.shape_id\",\"riegl.voxel_"
    "collapsed\",\"riegl.std_dev?\"],\"identifier\":\"vxls\",\"metadata\":[\"riegl.vo"
    "xel_info\",\"riegl.geo_tag?\"]}"
);

// Schema for ".wdcx" files
const std::string RDB_SCHEMA_RIEGL_WDCX(
    "{\"extension\":\"wdcx\",\"attributes\":[\"riegl.id\",\"riegl.timestamp\",\"riegl."
    "xyz*\",\"riegl.xyz_socs\",\"riegl.direction_medium\",\"riegl.amplitude\",\"rie"
    "gl.reflectance?\",\"riegl.deviation?\",\"riegl.pulse_width?\",\"riegl.target"
    "_index\",\"riegl.target_count\",\"riegl.mirror_facet?\",\"riegl.scan_segment"
    "?\",\"riegl.mta_unresolved?\",\"riegl.mta_zone?\",\"riegl.window_echo_impact"
    "_corrected?\",\"riegl.rgba?\",\"riegl.class?\",\"riegl.start_of_scan_line?\","
    "\"riegl.end_of_scan_line?\",\"riegl.source_indicator?\",\"riegl.fwa?\",\"rieg"
    "l.waveform_available?\",\"riegl.wfm_sbl_id?\",\"riegl.wfm_echo_time_offset"
    "?\",\"riegl.scan_angle\",\"riegl.scan_direction\",\"riegl.source_index?\",\"ri"
    "egl.hydro_intersection_point?\",\"riegl.hydro_intersection_normal?\"],\"id"
    "entifier\":\"wdcx\",\"metadata\":[\"riegl.atmosphere\",\"riegl.beam_geometry\","
    "\"riegl.device_geometry\",\"riegl.device\",\"riegl.gaussian_decomposition?\""
    ",\"riegl.exponential_decomposition?\",\"riegl.geo_tag\",\"riegl.georeferenc"
    "ing_parameters\",\"riegl.mta_settings?\",\"riegl.near_range_correction?\",\""
    "riegl.noise_estimates?\",\"riegl.angular_notch_filter?\",\"riegl.notch_fil"
    "ter?\",\"riegl.pointcloud_info?\",\"riegl.pulse_position_modulation?\",\"rie"
    "gl.range_statistics?\",\"riegl.receiver_internals?\",\"riegl.reflectance_c"
    "alculation?\",\"riegl.reflectance_correction?\",\"riegl.scan_pattern\",\"rie"
    "gl.time_base\",\"riegl.waveform_settings?\",\"riegl.window_analysis?\",\"rie"
    "gl.window_echo_correction?\"]}"
);

// Schema for ".wex" files
const std::string RDB_SCHEMA_RIEGL_WEX(
    "{\"extension\":\"wex\",\"attributes\":[\"riegl.id\",\"riegl.timestamp*\",\"riegl."
    "wex_filter_valid\",\"riegl.wex_point_count\",\"riegl.wex_amplitude\",\"riegl"
    ".wex_amplitude_std_dev\",\"riegl.wex_amplitude_min\",\"riegl.wex_amplitude"
    "_max\",\"riegl.wex_amplitude_offset\",\"riegl.wex_deviation\",\"riegl.wex_de"
    "viation_std_dev\",\"riegl.wex_deviation_min\",\"riegl.wex_deviation_max\",\""
    "riegl.wex_range\",\"riegl.wex_range_std_dev\",\"riegl.wex_range_min\",\"rieg"
    "l.wex_range_max\",\"riegl.wex_filter_range_min\",\"riegl.wex_filter_range_"
    "max\",\"riegl.wex_filter_amplitude_max\"],\"identifier\":\"wex\",\"metadata\":["
    "\"riegl.device\",\"riegl.notch_filter\",\"riegl.window_analysis\"]}"
);

// Table of all RDB file schema strings
const std::string RDB_SCHEMA_ARRAY[] = {
    RDB_SCHEMA_RIEGL_AVG_FWA,
    RDB_SCHEMA_RIEGL_AVG_SBX,
    RDB_SCHEMA_RIEGL_AVG_SIDX,
    RDB_SCHEMA_RIEGL_AVG_SPC,
    RDB_SCHEMA_RIEGL_CPX,
    RDB_SCHEMA_RIEGL_FWA,
    RDB_SCHEMA_RIEGL_MPX,
    RDB_SCHEMA_RIEGL_MTCH,
    RDB_SCHEMA_RIEGL_MVX,
    RDB_SCHEMA_RIEGL_OBSX,
    RDB_SCHEMA_RIEGL_OPEFX,
    RDB_SCHEMA_RIEGL_OPP,
    RDB_SCHEMA_RIEGL_OPX,
    RDB_SCHEMA_RIEGL_OWP,
    RDB_SCHEMA_RIEGL_PEFX,
    RDB_SCHEMA_RIEGL_PROJECT_POFX,
    RDB_SCHEMA_RIEGL_SCAN_POFX,
    RDB_SCHEMA_RIEGL_PROJECT_POQX,
    RDB_SCHEMA_RIEGL_SCAN_POQX,
    RDB_SCHEMA_RIEGL_PPX,
    RDB_SCHEMA_RIEGL_PROJECT_PTCH,
    RDB_SCHEMA_RIEGL_SCAN_PTCH,
    RDB_SCHEMA_RIEGL_SCANPOS_PTCH,
    RDB_SCHEMA_RIEGL_RDBX,
    RDB_SCHEMA_RIEGL_RMVX,
    RDB_SCHEMA_RIEGL_S10X,
    RDB_SCHEMA_RIEGL_SBX,
    RDB_SCHEMA_RIEGL_SDCX,
    RDB_SCHEMA_RIEGL_SIDX,
    RDB_SCHEMA_RIEGL_SODX,
    RDB_SCHEMA_RIEGL_SPC,
    RDB_SCHEMA_RIEGL_VTX,
    RDB_SCHEMA_RIEGL_VXLS,
    RDB_SCHEMA_RIEGL_WDCX,
    RDB_SCHEMA_RIEGL_WEX
};
const size_t RDB_SCHEMA_COUNT(
    sizeof(RDB_SCHEMA_ARRAY) / sizeof(RDB_SCHEMA_ARRAY[0])
);
const std::vector<std::string> RDB_SCHEMA_VECTOR(
    RDB_SCHEMA_ARRAY, RDB_SCHEMA_ARRAY + RDB_SCHEMA_COUNT
);

}}} // namespace riegl::rdb::pointcloud

#endif // RDB_6DC7FF98_C890_4397_90B3_45A2547A201F
