{*
 *******************************************************************************
 *
 *  Copyright 2020 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 *}
{*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 *
 *******************************************************************************
 *}

unit riegl.rdb.default.metadata;

{$WRITEABLECONST ON} // see section "initialization"

interface

// Meta data items definition version
const
  RDB_META_DATA_ITEMS_VERSION = '1.1.48';
  RDB_META_DATA_ITEMS_DATE = '2021-04-16';

// Meta data item states
const
  RDB_STATUS_REQUIRED = 1; // mandatory item
  RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
type
  TRDBPointcloudMetaDataItemInfo = record
    Name        : System.String;
    Title       : System.String;
    Description : System.String;
    Status      : System.Byte;
    Schema      : System.String;
    Example     : System.String;
  end;
  PRDBPointcloudMetaDataItemInfo = ^TRDBPointcloudMetaDataItemInfo;

// Angular notch filter parameters for window glass echoes
const
  RDB_RIEGL_ANGULAR_NOTCH_FILTER : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.angular_notch_filter';
    Title       : 'Angular Notch Filter';
    Description : 'Angular notch filter parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Angular notch filter parameters for window glass echoe'
      + 's","required":["angle","range_mean","amplitude_mean"],"type":"object",'
      + '"properties":{"angle":{"description":"Angle [deg]","items":{"type":"nu'
      + 'mber"},"type":"array"},"range_mean":{"description":"Mean range [m]","i'
      + 'tems":{"type":"number"},"type":"array"},"amplitude_mean":{"description'
      + '":"Mean amplitude '
      + '[dB]","items":{"type":"number"},"type":"array"}},"title":"Angular '
      + 'Notch Filter","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"angle":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0],"ran'
      + 'ge_mean":[0.094,0.094,0.09075,0.08675,0.0815,0.0775,0.074,0.071,0.068,'
      + '0.0675,0.06475],"amplitude_mean":[3.780913,3.780913,3.480913,3.120913,'
      + '2.850913,2.720913,2.680913,2.610913,2.530913,2.570913,2.570913]}'
    );
  );

// Atmospheric Parameters
const
  RDB_RIEGL_ATMOSPHERE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.atmosphere';
    Title       : 'Atmosphere';
    Description : 'Atmospheric Parameters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Atmospheric Parameters","required":["temperature","pre'
      + 'ssure","rel_humidity","pressure_sl","amsl","group_velocity","attenuati'
      + 'on","wavelength"],"type":"object","properties":{"wavelength":{"descrip'
      + 'tion":"Laser wavelength '
      + '[nm]","type":"number"},"attenuation":{"description":"Atmospheric '
      + 'attenuation '
      + '[1/km]","type":"number"},"temperature":{"description":"Temperature '
      + 'along measurement path '
      + '[\u00b0C]","type":"number"},"amsl":{"description":"Height above mean '
      + 'sea level (AMSL) '
      + '[m]","type":"number"},"group_velocity":{"description":"Group velocity '
      + 'of laser beam '
      + '[m/s]","type":"number"},"pressure":{"description":"Pressure along '
      + 'measurment path '
      + '[mbar]","type":"number"},"rel_humidity":{"description":"Relative '
      + 'humidity along measurement path '
      + '[%]","type":"number"},"pressure_sl":{"description":"Atmospheric '
      + 'pressure at sea level [mbar]","type":"number"}},"title":"Atmospheric '
      + 'Parameters","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"wavelength":1550,"attenuation":0.028125,"temperature":7,"amsl":0,"gr'
      + 'oup_velocity":299711000.0,"pressure":970,"rel_humidity":63,"pressure_s'
      + 'l":970}'
    );
  );

// Laser beam geometry details
const
  RDB_RIEGL_BEAM_GEOMETRY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.beam_geometry';
    Title       : 'Beam Geometry';
    Description : 'Laser beam geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Laser beam geometry details","required":["beam_exit_di'
      + 'ameter","beam_divergence"],"type":"object","properties":{"beam_diverge'
      + 'nce":{"description":"Beam divergence in far field [rad]","exclusiveMin'
      + 'imum":false,"minimum":0,"type":"number"},"beam_exit_diameter":{"descri'
      + 'ption":"Beam width at exit aperture [m]","exclusiveMinimum":false,"min'
      + 'imum":0,"type":"number"}},"title":"Beam '
      + 'Geometry","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"beam_divergence":0.0003,"beam_exit_diameter":0.0072}'
    );
  );

// List of control object type definitions
const
  RDB_RIEGL_CONTROL_OBJECT_CATALOG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.control_object_catalog';
    Title       : 'Control Object Catalog';
    Description : 'List of control object type definitions';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"List of control object type definitions","required":["'
      + 'types"],"type":"object","properties":{"types":{"items":{"oneOf":[{"$re'
      + 'f":"#/definitions/rectangle"},{"$ref":"#/definitions/checkerboard2x2"}'
      + ',{"$ref":"#/definitions/chevron"},{"$ref":"#/definitions/circular_disk'
      + '"},{"$ref":"#/definitions/cylinder"},{"$ref":"#/definitions/sphere"},{'
      + '"$ref":"#/definitions/round_corner_cube_prism"}],"type":"object"},"uni'
      + 'queItems":true,"type":"array"}},"title":"Control Object Catalog","defi'
      + 'nitions":{"chevron":{"description":"chevron","allOf":[{"$ref":"#/defin'
      + 'itions/common"},{"description":"chevron specific '
      + 'properties","properties":{"shape":{"description":"shape identifier","e'
      + 'num":["chevron"],"type":"string"},"outside_edge_length":{"description"'
      + ':"length of the two outer edges in meters","exclusiveMinimum":true,"mi'
      + 'nimum":0,"type":"number"},"thickness":{"description":"thickness in met'
      + 'ers","exclusiveMinimum":true,"minimum":0,"type":"number"}},"required":'
      + '["shape","outside_edge_length","thickness"],"type":"object"}],"type":"'
      + 'object"},"common":{"description":"common object '
      + 'properties","properties":{"description":{"description":"string '
      + 'describing the object","type":"string"},"shape":{"description":"shape '
      + 'identifier","enum":["rectangle","checkerboard2x2","chevron","circular_'
      + 'disk","cylinder","sphere","round_corner_cube_prism"],"type":"string"},'
      + '"name":{"description":"unique type identifier","minLength":3,"type":"s'
      + 'tring"},"surface_type":{"description":"surface material type","enum":['
      + '"retro_reflective_foil","diffuse"],"type":"string"}},"required":["name'
      + '","shape"],"type":"object"},"circular_disk":{"description":"circular d'
      + 'isk","allOf":[{"$ref":"#/definitions/common"},{"description":"circular'
      + ' disk specific '
      + 'properties","properties":{"offset":{"description":"offset in meters, '
      + 'e.g. reflector constant '
      + '(optional)","type":"number"},"shape":{"description":"shape identifier"'
      + ',"enum":["circular_disk"],"type":"string"},"diameter":{"description":"'
      + 'diameter in meters","exclusiveMinimum":true,"minimum":0,"type":"number'
      + '"}},"required":["shape","diameter"],"type":"object"}],"type":"object"}'
      + ',"rectangle":{"description":"rectangle","allOf":[{"$ref":"#/definition'
      + 's/common"},{"description":"rectangle specific '
      + 'properties","properties":{"width":{"description":"width in meters","ex'
      + 'clusiveMinimum":true,"minimum":0,"type":"number"},"shape":{"enum":["re'
      + 'ctangle"],"type":"string"},"length":{"description":"length in meters",'
      + '"exclusiveMinimum":true,"minimum":0,"type":"number"}},"required":["sha'
      + 'pe","length","width"],"type":"object"}],"type":"object"},"sphere":{"de'
      + 'scription":"sphere","allOf":[{"$ref":"#/definitions/common"},{"descrip'
      + 'tion":"sphere specific '
      + 'properties","properties":{"shape":{"description":"shape identifier","e'
      + 'num":["sphere"],"type":"string"},"diameter":{"description":"diameter '
      + 'in meters","exclusiveMinimum":true,"minimum":0,"type":"number"}},"requ'
      + 'ired":["shape","diameter"],"type":"object"}],"type":"object"},"checker'
      + 'board2x2":{"description":"checkerboard 2 by 2","allOf":[{"$ref":"#/def'
      + 'initions/common"},{"description":"checkerboard specific '
      + 'properties","properties":{"square_length":{"description":"length of a '
      + 'square of the checkerboard in meters","exclusiveMinimum":true,"minimum'
      + '":0,"type":"number"},"shape":{"description":"shape identifier","enum":'
      + '["checkerboard2x2"],"type":"string"}},"required":["shape","square_leng'
      + 'th"],"type":"object"}],"type":"object"},"cylinder":{"description":"cyl'
      + 'inder","allOf":[{"$ref":"#/definitions/common"},{"description":"cylind'
      + 'er specific properties","properties":{"height":{"description":"height '
      + 'in meters","exclusiveMinimum":true,"minimum":0,"type":"number"},"shape'
      + '":{"description":"shape identifier","enum":["cylinder"],"type":"string'
      + '"},"diameter":{"description":"diameter in meters","exclusiveMinimum":t'
      + 'rue,"minimum":0,"type":"number"}},"required":["shape","diameter","heig'
      + 'ht"],"type":"object"}],"type":"object"},"round_corner_cube_prism":{"de'
      + 'scription":"round corner cube '
      + 'prism","allOf":[{"$ref":"#/definitions/common"},{"description":"round '
      + 'corner cube prism specific '
      + 'properties","properties":{"offset":{"description":"offset in meters, '
      + 'e.g. reflector constant '
      + '(optional)","type":"number"},"shape":{"description":"shape identifier"'
      + ',"enum":["round_corner_cube_prism"],"type":"string"},"diameter":{"desc'
      + 'ription":"diameter in meters","exclusiveMinimum":true,"minimum":0,"typ'
      + 'e":"number"}},"required":["shape","diameter"],"type":"object"}],"type"'
      + ':"object"}},"$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"comments":["This file contains a list of control object types (aka. '
      + '''catalog'').","Each type is described by an object,","which must '
      + 'contain at least the following parameters:","  - name: unique '
      + 'identifier of the type","  - shape: one of the following supported '
      + 'shapes:","      - rectangle","      - checkerboard2x2","      - '
      + 'chevron","      - circular_disk","      - cylinder","      - sphere","'
      + '      - round_corner_cube_prism","Depending on ''shape'', the following '
      + 'parameters must/may be specified:","  - rectangle:","      - length: '
      + 'length in meters","      - width: width in meters","  - '
      + 'checkerboard2x2:","      - square_length: length of a square of the '
      + 'checkerboard in meters","  - circular_disk:","      - diameter: '
      + 'diameter in meters","      - offset: offset in meters, e.g. reflector '
      + 'constant (optional)","  - chevron:","      - outside_edge_length: '
      + 'length of the two outer edges in meters","      - thickness: thickness'
      + ' in meters","  - cylinder:","      - diameter: diameter in meters","'
      + '      - height:  height in meters","  - sphere:","      - diameter: '
      + 'diameter in meters","  - round_corner_cube_prism:","      - diameter: '
      + 'diameter in meters","      - offset: offset in meters, e.g. reflector '
      + 'constant (optional)","Optional parameters:","    - description: string'
      + ' describing the object","    - surface_type: surface material type '
      + '(either ''retro_reflective_foil'' or '
      + '''diffuse'')"],"types":[{"description":"Rectangle (60cm x '
      + '30cm)","width":0.3,"shape":"rectangle","name":"Rectangle '
      + '60x30","length":0.6},{"description":"Rectangle (80cm x '
      + '40cm)","width":0.4,"shape":"rectangle","name":"Rectangle '
      + '80x40","length":0.8},{"description":"Checkerboard (square length: 30cm'
      + ')","square_length":0.3,"shape":"checkerboard2x2","name":"Checkerboard2'
      + 'x2 30"},{"description":"Checkerboard (square length: 50cm)","square_le'
      + 'ngth":0.5,"shape":"checkerboard2x2","name":"Checkerboard2x2 '
      + '50"},{"description":"Chevron (a=24''''; '
      + 'b=4'''')","shape":"chevron","outside_edge_length":0.6096,"name":"Chevron'
      + ' 24''''/4''''","thickness":0.1016},{"description":" Circular Disk '
      + '(diameter: 50cm)","shape":"circular_disk","name":"Circular Disk '
      + '50","diameter":0.5,"surface_type":"diffuse"},{"description":"flat '
      + 'circular reflector from retro-reflective '
      + 'foil","offset":0.0,"shape":"circular_disk","name":"RIEGL flat '
      + 'reflector 50 mm","diameter":0.05,"surface_type":"retro_reflective_foil'
      + '"},{"description":"flat circular reflector from retro-reflective '
      + 'foil","offset":0.0,"shape":"circular_disk","name":"RIEGL flat '
      + 'reflector 100 mm","diameter":0.1,"surface_type":"retro_reflective_foil'
      + '"},{"description":"flat circular reflector from retro-reflective '
      + 'foil","offset":0.0,"shape":"circular_disk","name":"RIEGL flat '
      + 'reflector 150 mm","diameter":0.15,"surface_type":"retro_reflective_foi'
      + 'l"},{"description":"cylindrical reflector from retro-reflective '
      + 'foil","shape":"cylinder","name":"RIEGL cylindrical reflector 50 mm","h'
      + 'eight":0.05,"diameter":0.05,"surface_type":"retro_reflective_foil"},{"'
      + 'description":"cylindrical reflector from retro-reflective '
      + 'foil","shape":"cylinder","name":"RIEGL cylindrical reflector 100 mm","'
      + 'height":0.1,"diameter":0.1,"surface_type":"retro_reflective_foil"},{"d'
      + 'escription":"Sphere (diameter: 200 '
      + 'mm)","shape":"sphere","name":"Sphere 200 '
      + 'mm","diameter":0.2},{"description":"round corner cube '
      + 'prism","offset":0.0,"shape":"round_corner_cube_prism","name":"Corner '
      + 'Cube Prism 50 mm","diameter":0.05}]}'
    );
  );

// Details about the control object reference file
const
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.control_object_reference_file';
    Title       : 'Control Object Reference file';
    Description : 'Details about the control object reference file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about the control object reference '
      + 'file","properties":{"reference_file":{"description":"Reference to a '
      + 'control object file","properties":{"file_uuid":{"description":"Control'
      + ' object file''s Universally Unique Identifier (RFC '
      + '4122)","type":"string"},"file_path":{"description":"Path of the '
      + 'control object file relative to referring file","type":"string"}},"req'
      + 'uired":["file_uuid","file_path"],"type":"object"}},"type":"object","ti'
      + 'tle":"Control Object Reference '
      + 'file","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"reference_file":{"file_uuid":"810f5d57-eccf-49ed-b07a-0cdd109b4213",'
      + '"file_path":"../../../10_CONTROL_OBJECTS/ControlPoints.cpx"}}'
    );
  );

// Detection probability as a function of amplitude
const
  RDB_RIEGL_DETECTION_PROBABILITY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.detection_probability';
    Title       : 'Detection Probability';
    Description : 'Detection probability as a function of amplitude';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Detection probability as a function of amplitude","req'
      + 'uired":["amplitude","detection_probability"],"type":"object","properti'
      + 'es":{"amplitude":{"description":"Amplitude [dB]","items":{"type":"numb'
      + 'er"},"type":"array"},"detection_probability":{"description":"Detection'
      + ' probability '
      + '[0..1]","items":{"type":"number"},"type":"array"}},"title":"Detection '
      + 'Probability","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"amplitude":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0],"detection'
      + '_probability":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]}'
    );
  );

// Details about the device used to acquire the point cloud
const
  RDB_RIEGL_DEVICE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device';
    Title       : 'Device Information';
    Description : 'Details about the device used to acquire the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about the device used to acquire the point clo'
      + 'ud","required":["device_type","serial_number"],"type":"object","proper'
      + 'ties":{"channel_text":{"description":"Optional channel description '
      + '(e.g. ''Green Channel'' for multi-channel '
      + 'devices)","type":"string"},"device_name":{"description":"Optional '
      + 'device name (e.g. ''Scanner 1'' for multi-scanner '
      + 'systems)","type":"string"},"device_type":{"description":"Device type '
      + 'identifier (e.g. '
      + 'VZ-400i)","type":"string"},"serial_number":{"description":"Device '
      + 'serial number (e.g. '
      + 'S2221234)","type":"string"},"device_build":{"description":"Device '
      + 'build variant","type":"string"},"channel_number":{"description":"Laser'
      + ' channel number (not defined or 0: single channel device)","exclusiveM'
      + 'inimum":false,"minimum":0,"type":"integer"}},"title":"Device '
      + 'Information","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"channel_text":"","device_name":"Scanner 1","device_type":"VZ-400i","'
      + 'serial_number":"S2221234","device_build":"","channel_number":0}'
    );
  );

// Scanner device geometry details
const
  RDB_RIEGL_DEVICE_GEOMETRY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_geometry';
    Title       : 'Device Geometry';
    Description : 'Scanner device geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Scanner device geometry details","required":["primary"'
      + '],"type":"object","properties":{"amu":{"description":"Angle '
      + 'Measurement Unit","properties":{"frameCC":{"description":"Frame Circle'
      + ' Count (number of LSBs per full rotation about frame axis)","exclusive'
      + 'Minimum":false,"minimum":0,"type":"number"},"lineCC":{"description":"L'
      + 'ine Circle Count (number of LSBs per full rotation about line axis)","'
      + 'exclusiveMinimum":false,"minimum":0,"type":"number"}},"type":"object"}'
      + ',"primary":{"description":"Primary device geometry structure '
      + '(mandatory)","properties":{"content":{"description":"Internal '
      + 'calibration values","items":{"type":"number"},"type":"array"},"ID":{"d'
      + 'escription":"Structure identifier","items":{"type":"integer"},"minItem'
      + 's":2,"maxItems":2,"type":"array"}},"required":["ID","content"],"type":'
      + '"object"},"secondary":{"description":"Additional device geometry '
      + 'structure (optional)","properties":{"content":{"description":"Internal'
      + ' calibration values","items":{"type":"number"},"type":"array"},"ID":{"'
      + 'description":"Structure identifier","items":{"type":"integer"},"minIte'
      + 'ms":2,"maxItems":2,"type":"array"}},"required":["ID","content"],"type"'
      + ':"object"}},"title":"Device '
      + 'Geometry","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"amu":{"frameCC":124000,"lineCC":124000},"primary":{"content":[0],"ID'
      + '":[4,0]},"secondary":{"content":[0],"ID":[91,0]}}'
    );
  );

// Scanner passive channel device geometry details
const
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_geometry_passive_channel';
    Title       : 'Device Geometry Passive Channel';
    Description : 'Scanner passive channel device geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Scanner passive channel device geometry details","requ'
      + 'ired":["primary"],"type":"object","properties":{"primary":{"descriptio'
      + 'n":"Primary device geometry structure '
      + '(mandatory)","properties":{"content":{"description":"Internal '
      + 'calibration values","items":{"type":"number"},"type":"array"},"ID":{"d'
      + 'escription":"Structure identifier","items":{"type":"integer"},"minItem'
      + 's":2,"maxItems":2,"type":"array"}},"required":["ID","content"],"type":'
      + '"object"}},"title":"Device Geometry Passive '
      + 'Channel","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"primary":{"content":[0],"ID":[143,0]}}'
    );
  );

// Limits of the measured values output by the device
const
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_output_limits';
    Title       : 'Device Output Limits';
    Description : 'Limits of the measured values output by the device';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Limits of the measured values output by the device. '
      + 'The limits depend on the device type, measurement program and/or scan '
      + 'pattern.","properties":{"background_radiation_minimum":{"description":'
      + '"Minimum possible background radiation.","type":"number"},"background_'
      + 'radiation_maximum":{"description":"Maximum possible background radiati'
      + 'on.","type":"number"},"reflectance_maximum":{"description":"Maximum '
      + 'possible reflectance in '
      + 'dB.","type":"number"},"echo_count_maximum":{"description":"Maximum '
      + 'number of echoes a laser shot can '
      + 'have.","type":"number"},"amplitude_minimum":{"description":"Minimum '
      + 'possible amplitude in '
      + 'dB.","type":"number"},"deviation_maximum":{"description":"Maximum '
      + 'possible pulse shape '
      + 'deviation.","type":"number"},"range_minimum":{"description":"Minimum '
      + 'possible range in '
      + 'meters.","type":"number"},"range_maximum":{"description":"Maximum '
      + 'possible range in meters.","type":"number"},"mta_zone_count_maximum":{'
      + '"description":"Maximum number of MTA '
      + 'zones.","type":"number"},"amplitude_maximum":{"description":"Maximum '
      + 'possible amplitude in '
      + 'dB.","type":"number"},"deviation_minimum":{"description":"Minimum '
      + 'possible pulse shape deviation.","type":"number"},"reflectance_minimum'
      + '":{"description":"Minimum possible reflectance in '
      + 'dB.","type":"number"}},"type":"object","title":"Device Output '
      + 'Limits","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"background_radiation_minimum":0,"deviation_maximum":32767,"backgroun'
      + 'd_radiation_maximum":0,"range_minimum":2.9,"range_maximum":10000.0,"mt'
      + 'a_zone_count_maximum":7,"deviation_minimum":-1,"amplitude_maximum":100'
      + '.0,"reflectance_maximum":100.0,"reflectance_minimum":-100.0,"amplitude'
      + '_minimum":0.0}'
    );
  );

// Details about echo files
const
  RDB_RIEGL_ECHO_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.echo_info';
    Title       : 'Echo Information';
    Description : 'Details about echo files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about echo files","required":["echo_file"],"ty'
      + 'pe":"object","properties":{"echo_file":{"properties":{"file_uuid":{"de'
      + 'scription":"File''s Universally Unique Identifier (RFC '
      + '4122)","type":"string"},"file_extension":{"description":"Echo file '
      + 'extension, without the leading dot","type":"string"}},"required":["fil'
      + 'e_extension"],"type":"object"}},"title":"Echo '
      + 'Information","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"echo_file":{"file_uuid":"26a03615-67c0-4bea-8fe8-c577378fe661","file'
      + '_extension":"owp"}}'
    );
  );

// Details for exponential decomposition of full waveform data
const
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.exponential_decomposition';
    Title       : 'Exponential Decomposition';
    Description : 'Details for exponential decomposition of full waveform data';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details for exponential decomposition of full waveform'
      + ' data","additionalProperties":false,"type":"object","patternProperties'
      + '":{"^[0-9]+$":{"description":"one field per channel, field name is '
      + 'channel index","$ref":"#/definitions/channel"}},"title":"Exponential D'
      + 'ecomposition","definitions":{"channel":{"properties":{"delay":{"descri'
      + 'ption":"delay calibration in '
      + 'seconds","type":"number"},"scale":{"description":"amplitude '
      + 'calibration","type":"number"},"a_lin":{"description":"relative linear '
      + 'amplitude range [0..1]","maximum":1,"type":"number","exclusiveMaximum"'
      + ':false,"exclusiveMinimum":false,"minimum":0},"parameter":{"description'
      + '":"parameters of the syswave exponential '
      + 'sum","properties":{"B":{"description":"imaginary part of amplitude '
      + 'factor in units of full-scale","items":{"type":"number"},"type":"array'
      + '"},"A":{"description":"real part of amplitude factor in units of full-'
      + 'scale","items":{"type":"number"},"type":"array"},"omega":{"description'
      + '":"angular frequency in Hz","items":{"type":"number"},"type":"array"},'
      + '"gamma":{"description":"decay in 1/second","items":{"type":"number"},"'
      + 'type":"array"}},"required":["A","B","gamma","omega"],"type":"object"}}'
      + ',"required":["delay","scale","parameter"],"type":"object"}},"$schema":'
      + '"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"0":{"delay":3.783458418887631e-09,"scale":1.0,"a_lin":0.27,"paramete'
      + 'r":{"B":[-3.9813032150268555,0.08622030913829803,-0.3152860999107361],'
      + '"A":[0.9772450923919678,0.3354335129261017,-1.312678575515747],"omega"'
      + ':[352020896.0,3647927552.0,-1977987072.0],"gamma":[-1094726528.0,-7695'
      + '62752.0,-848000064.0]}},"1":{"delay":3.5e-09,"scale":1.0,"a_lin":0.9,"'
      + 'parameter":{"B":[-3.9,0.0,-0.3],"A":[0.9,0.3,-1.3],"omega":[352020896.'
      + '0,3647927552.0,-1977987072.0],"gamma":[-1094726528.0,-769562752.0,-848'
      + '000064.0]}}}'
    );
  );

// Details for Gaussian decomposition of full waveform data
const
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.gaussian_decomposition';
    Title       : 'Gaussian Decomposition';
    Description : 'Details for Gaussian decomposition of full waveform data';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"riegl.gaussian_decomposition contains information '
      + 'relevant for extracting calibrated amplitudes and calibrated ranges '
      + 'from a Gaussian decomposition of full waveform data. This information '
      + 'is contained in a table with five columns. Two columns are to be used '
      + 'as input: amplitude_lsb_low_power and amplitude_lsb_high_power. The '
      + 'other three columns provide the outputs. Amplitude_db gives the '
      + 'calibrated amplitude in the optical regime in decibels. The range '
      + 'offset columns provide additive range offsets, given in units of '
      + 'seconds, for each channel.","required":["amplitude_lsb_low_power","amp'
      + 'litude_lsb_high_power","amplitude_db","range_offset_sec_low_power","ra'
      + 'nge_offset_sec_high_power"],"type":"object","properties":{"range_offse'
      + 't_sec_low_power":{"items":{"type":"number"},"type":"array"},"amplitude'
      + '_db":{"items":{"type":"number"},"type":"array"},"amplitude_lsb_low_pow'
      + 'er":{"items":{"type":"number"},"type":"array"},"amplitude_lsb_high_pow'
      + 'er":{"items":{"type":"number"},"type":"array"},"range_offset_sec_high_'
      + 'power":{"items":{"type":"number"},"type":"array"}},"title":"Gaussian '
      + 'Decomposition","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"range_offset_sec_low_power":[],"amplitude_db":[],"amplitude_lsb_low_'
      + 'power":[],"amplitude_lsb_high_power":[],"range_offset_sec_high_power":'
      + '[]}'
    );
  );

// Point cloud Georeferencing Information
const
  RDB_RIEGL_GEO_TAG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.geo_tag';
    Title       : 'Geo Tag';
    Description : 'Point cloud Georeferencing Information';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Point cloud Georeferencing '
      + 'Information","properties":{"pose":{"description":"Coordinate '
      + 'Transformation Matrix to transform from File Coordinate System to '
      + 'Global Coordinate Reference System. 4x4 matrix stored as two '
      + 'dimensional array, row major order.","items":{"description":"rows","it'
      + 'ems":{"description":"columns","type":"number"},"minItems":4,"maxItems"'
      + ':4,"type":"array"},"minItems":4,"maxItems":4,"type":"array"},"crs":{"d'
      + 'escription":"Global Coordinate Reference System. Please note that only'
      + ' 3D Cartesian Coordinate Systems are '
      + 'allowed.","properties":{"wkt":{"description":"\"Well-Known Text\" '
      + 'string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w'
      + 'kt-crs)","type":"string"},"epsg":{"description":"EPSG '
      + 'code","minimum":0,"type":"integer"},"name":{"description":"Coordinate '
      + 'reference system '
      + 'name","type":"string"}},"type":"object"}},"type":"object","title":"Geo'
      + ' Tag","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"pose":[[-0.269827776749716,-0.723017716139738,0.635954678449952,4063'
      + '882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847,113'
      + '8787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196],[0'
      + '.0,0.0,0.0,1.0]],"crs":{"wkt":"GEOCCS[\"WGS84 Geocentric\",DATUM[\"WGS'
      + '84\",SPHEROID[\"WGS84\",6378137.000,298.257223563,AUTHORITY[\"EPSG\",\'
      + '"7030\"]],AUTHORITY[\"EPSG\",\"6326\"]],PRIMEM[\"Greenwich\",0.0000000'
      + '000000000,AUTHORITY[\"EPSG\",\"8901\"]],UNIT[\"Meter\",1.0000000000000'
      + '0000000,AUTHORITY[\"EPSG\",\"9001\"]],AXIS[\"X\",OTHER],AXIS[\"Y\",EAS'
      + 'T],AXIS[\"Z\",NORTH],AUTHORITY[\"EPSG\",\"4978\"]]","epsg":4978,"name"'
      + ':"WGS84 Geocentric"}}'
    );
  );

// Geometric Scale Factor applied to point coordinates
const
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.geometric_scale_factor';
    Title       : 'Geometric Scale Factor';
    Description : 'Geometric Scale Factor applied to point coordinates';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Geometric Scale Factor applied to point coordinates","'
      + 'exclusiveMinimum":true,"type":"number","minimum":0,"$schema":"http://j'
      + 'son-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '1.0'
    );
  );

// Parameters used for georeferencing of the point cloud
const
  RDB_RIEGL_GEOREFERENCING_PARAMETERS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.georeferencing_parameters';
    Title       : 'Georeferencing Parameters';
    Description : 'Parameters used for georeferencing of the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Parameters used for georeferencing of the point '
      + 'cloud","properties":{"trajectory_offsets":{"description":"Correction '
      + 'offsets applied to the trajectory '
      + 'data","properties":{"version":{"description":"Meaning of offset values'
      + ' and how to apply them; version 0: '
      + 'Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), '
      + 'version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(yaw_offset)*Ry(pitch_offset'
      + ')*Rx(roll_offset)","type":"integer"},"offset_yaw":{"description":"[deg'
      + ']","type":"number"},"offset_roll":{"description":"[deg]","type":"numbe'
      + 'r"},"offset_east":{"description":"[m]","type":"number"},"offset_time":'
      + '{"description":"[s]","type":"number"},"offset_pitch":{"description":"['
      + 'deg]","type":"number"},"offset_north":{"description":"[m]","type":"num'
      + 'ber"},"offset_height":{"description":"[m]","type":"number"}},"type":"o'
      + 'bject"},"body_coordinate_system_type":{"description":"BODY coordinate '
      + 'frame (NED: North-East-Down, ENU: East-North-Up), default: NED","enum"'
      + ':["NED","ENU"],"type":"string"},"trajectory_file":{"description":"Traj'
      + 'ectory data used for georeferencing of the point '
      + 'cloud","properties":{"file_uuid":{"description":"File''s Universally '
      + 'Unique Identifier (RFC '
      + '4122)","type":"string"},"file_extension":{"description":"Trajectory '
      + 'file extension, without the leading dot","type":"string"}},"required":'
      + '["file_extension"],"type":"object"},"socs_to_rocs_matrix":{"descriptio'
      + 'n":"Coordinate Transformation Matrix to transform from Scanner''s Own '
      + 'Coordinate System to Record Coordinate System. 4x4 matrix stored as '
      + 'two dimensional array, row major order.","items":{"description":"rows"'
      + ',"items":{"description":"columns","type":"number"},"minItems":4,"maxIt'
      + 'ems":4,"type":"array"},"minItems":4,"maxItems":4,"type":"array"},"socs'
      + '_to_body_matrix":{"description":"Coordinate Transformation Matrix to '
      + 'transform from Scanner''s Own Coordinate System to Body Coordinate '
      + 'System. 4x4 matrix stored as two dimensional array, row major order.",'
      + '"items":{"description":"rows","items":{"description":"columns","type":'
      + '"number"},"minItems":4,"maxItems":4,"type":"array"},"minItems":4,"maxI'
      + 'tems":4,"type":"array"}},"type":"object","title":"Georeferencing '
      + 'Parameters","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"trajectory_offsets":{"version":0,"offset_yaw":-0.45,"offset_roll":0.'
      + '03,"offset_east":0.15,"offset_time":18.007,"offset_pitch":0.01,"offset'
      + '_north":0.07,"offset_height":-0.2},"trajectory_file":{"file_uuid":"93a'
      + '03615-66c0-4bea-8ff8-c577378fe660","file_extension":"pofx"},"body_coor'
      + 'dinate_system_type":"NED","socs_to_body_matrix":[[-0.269827776749716,-'
      + '0.723017716139738,0.635954678449952,0.0],[0.962908599449764,-0.2026051'
      + '7250352,0.178208229833847,0.0],[0.0,0.660451759194338,0.7508684796801,'
      + '0.0],[0.0,0.0,0.0,1.0]]}'
    );
  );

// License keys for software features
const
  RDB_RIEGL_LICENSES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.licenses';
    Title       : 'Software License Keys';
    Description : 'License keys for software features';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"License keys for software features","additionalPropert'
      + 'ies":false,"type":"object","patternProperties":{"^.*$":{"description":'
      + '"Each field of the object represents a feature and holds a list of '
      + 'license keys, where the field name is the feature '
      + 'name.","items":{"description":"License key (example: ''46AE032A - '
      + '39882AC4 - 9EC0A184 - 6F163D73'')","type":"string"},"minItems":1,"type"'
      + ':"array"}},"title":"Software License '
      + 'Keys","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"Georeferencing":["46AE032A - 39882AC4 - 9EC0A184 - 6F163D73"],"MTA '
      + 'resolution":["468E020A - 39A922E4 - B681A184 - 673E3D72"],"Full '
      + 'Waveform Analysis Topography with GPU support":["8AB44126 - 23B92250 -'
      + ' 16E2689F - 34EF7E7B"],"Full Waveform Analysis Topography":["0FD5FF07 '
      + '- 011A1255 - 9F76CACA - 8D2ED557"]}'
    );
  );

// Parameters for MTA processing
const
  RDB_RIEGL_MTA_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.mta_settings';
    Title       : 'MTA Settings';
    Description : 'Parameters for MTA processing';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Parameters for MTA '
      + 'processing","properties":{"zone_width":{"description":"Width of a MTA '
      + 'zone in meter.","minimum":0,"type":"number"},"modulation_depth":{"desc'
      + 'ription":"Depth of pulse position modulation in meter.","minimum":0,"t'
      + 'ype":"number"},"zone_count":{"description":"Maximum number of MTA zone'
      + 's.","maximum":255,"minimum":0,"type":"integer"}},"type":"object","titl'
      + 'e":"MTA Settings","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"zone_width":149.896225,"modulation_depth":9.368514,"zone_count":23}'
    );
  );

// Lookup table for range correction based on raw range
const
  RDB_RIEGL_NEAR_RANGE_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.near_range_correction';
    Title       : 'Near Range Correction Table';
    Description : 'Lookup table for range correction based on raw range';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Lookup table for range correction based on raw range",'
      + '"required":["delta","content"],"type":"object","properties":{"content"'
      + ':{"description":"Correction value [m] to be added to the raw range","i'
      + 'tems":{"type":"number"},"minItems":1,"maxItems":2000,"type":"array"},"'
      + 'delta":{"description":"Delta between table entries [m], first entry is'
      + ' at range = 0 m","type":"number"}},"title":"Near Range Correction '
      + 'Table","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"content":[0.0],"delta":0.512}'
    );
  );

// Standard deviation for range and amplitude as a function of amplitude
const
  RDB_RIEGL_NOISE_ESTIMATES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.noise_estimates';
    Title       : 'Noise Estimates';
    Description : 'Standard deviation for range and amplitude as a function of amplitude';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Standard deviation for range and amplitude as a '
      + 'function of amplitude","required":["amplitude","range_sigma","amplitud'
      + 'e_sigma"],"type":"object","properties":{"range_sigma":{"description":"'
      + 'Sigma range [m]","items":{"type":"number"},"type":"array"},"amplitude"'
      + ':{"description":"Amplitude [dB]","items":{"type":"number"},"type":"arr'
      + 'ay"},"amplitude_sigma":{"description":"Sigma amplitude '
      + '[dB]","items":{"type":"number"},"type":"array"}},"title":"Noise '
      + 'Estimates","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"range_sigma":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.018,'
      + '0.016,0.014],"amplitude":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0'
      + '],"amplitude_sigma":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0.'
      + '432,0.39,0.354]}'
    );
  );

// Notch filter parameters for window glass echoes
const
  RDB_RIEGL_NOTCH_FILTER : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.notch_filter';
    Title       : 'Notch Filter';
    Description : 'Notch filter parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Notch filter parameters for window glass echoes","requ'
      + 'ired":["range_minimum","range_maximum","amplitude_maximum"],"type":"ob'
      + 'ject","properties":{"amplitude_maximum":{"description":"Maximum '
      + 'amplitude [dB]","minimum":0,"type":"number"},"range_minimum":{"descrip'
      + 'tion":"Minimum range '
      + '[m]","type":"number"},"range_maximum":{"description":"Maximum range '
      + '[m]","type":"number"}},"title":"Notch '
      + 'Filter","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"amplitude_maximum":18.0,"range_minimum":-0.5,"range_maximum":0.2}'
    );
  );

// Details about the pixels contained in the file
const
  RDB_RIEGL_PIXEL_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pixel_info';
    Title       : 'Pixel Information';
    Description : 'Details about the pixels contained in the file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about the pixels contained in the file","requi'
      + 'red":["size"],"type":"object","properties":{"size":{"$ref":"#/definiti'
      + 'ons/pixel_size","description":"Size of pixels in file coordinate syste'
      + 'm."},"size_llcs":{"$ref":"#/definitions/pixel_size","description":"Siz'
      + 'e of pixels in a locally levelled cartesian coordinate system (xy). '
      + 'This is only used for pixels based on a map '
      + 'projection."}},"title":"Pixel '
      + 'Information","definitions":{"pixel_size":{"description":"Size of '
      + 'pixels.","items":{"description":"Length of pixel edge [m].","minimum":'
      + '0,"type":"number"},"minItems":2,"maxItems":2,"type":"array"}},"$schema'
      + '":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"size":[0.5971642834779395,0.5971642834779395],"size_llcs":[0.5156575'
      + '252891171,0.5130835356683303]}'
    );
  );

// Details about the plane patch matching process
const
  RDB_RIEGL_PLANE_PATCH_MATCHING : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_patch_matching';
    Title       : 'Plane Patch Matching';
    Description : 'Details about the plane patch matching process';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about the plane patch matching process","requi'
      + 'red":["plane_patch_file_one","plane_patch_file_two"],"type":"object","'
      + 'properties":{"plane_patch_file_two":{"$ref":"#/definitions/file_refere'
      + 'nce","description":"Reference to the plane patch file two"},"plane_pat'
      + 'ch_file_one":{"$ref":"#/definitions/file_reference","description":"Ref'
      + 'erence to the plane patch file one"}},"title":"Plane Patch '
      + 'Matching","definitions":{"file_reference":{"description":"Reference to'
      + ' a plane patch file","properties":{"file_uuid":{"description":"Plane '
      + 'patch file''s Universally Unique Identifier (RFC '
      + '4122)","type":"string"},"file_path":{"description":"Path of the plane '
      + 'patch file relative to the match file","type":"string"}},"required":["'
      + 'file_uuid","file_path"],"type":"object"}},"$schema":"http://json-schem'
      + 'a.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"plane_patch_file_two":{"file_uuid":"fa47d509-a64e-49ce-8b14-ff3130fb'
      + 'efa9","file_path":"project.ptch"},"plane_patch_file_one":{"file_uuid":'
      + '"810f5d57-eccf-49ed-b07a-0cdd109b4213","file_path":"Record009_Line001/'
      + '191025_121410_Scanner_1.ptch"}}'
    );
  );

// Statistics about plane patches found by Plane Patch Extractor
const
  RDB_RIEGL_PLANE_PATCH_STATISTICS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_patch_statistics';
    Title       : 'Plane Patch Statistics';
    Description : 'Statistics about plane patches found by Plane Patch Extractor';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Statistics about plane patches found by Plane Patch '
      + 'Extractor","properties":{"total_horizontal_area":{"description":"sum '
      + 'of all plane patch areas projected to horizontal plane '
      + '[m\u00b2]","type":"number"},"total_area":{"description":"sum of all '
      + 'plane patch areas '
      + '[m\u00b2]","type":"number"}},"type":"object","title":"Plane Patch '
      + 'Statistics","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"total_horizontal_area":13954.601,"total_area":14007.965}'
    );
  );

// Settings and classes for plane slope classification
const
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_slope_class_info';
    Title       : 'Plane Slope Class Info';
    Description : 'Settings and classes for plane slope classification';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Settings and classes for plane slope classification","'
      + 'required":["settings","classes"],"type":"object","properties":{"settin'
      + 'gs":{"description":"Classification settings, details see documentation'
      + ' of rdbplanes","oneOf":[{"$ref":"#/definitions/method-1"},{"$ref":"#/d'
      + 'efinitions/method-2"}],"type":"object"},"classes":{"description":"Clas'
      + 's definition table","additionalProperties":false,"patternProperties":{'
      + '"^[0-9]+$":{"description":"one field per class, field name is class '
      + 'number, field value is class '
      + 'name","type":"string"}},"type":"object"}},"title":"Plane Slope Class '
      + 'Info","definitions":{"method-2":{"description":"Classification method '
      + '2","properties":{"sloping_plane_classes_minimum_angle":{"description":'
      + '"minimum inclination angle of sloping plane patches [deg]","maximum":3'
      + '60.0,"minimum":-360.0,"type":"number"},"sloping_plane_classes_maximum_'
      + 'angle":{"description":"maximum inclination angle of sloping plane '
      + 'patches [deg]","maximum":360.0,"minimum":-360.0,"type":"number"},"plan'
      + 'e_classification_method":{"description":"method ID (=2)","maximum":2,"'
      + 'minimum":2,"type":"integer"}},"required":["plane_classification_method'
      + '","sloping_plane_classes_minimum_angle","sloping_plane_classes_maximum'
      + '_angle"],"type":"object"},"method-1":{"description":"Classification '
      + 'method 1","properties":{"maximum_inclination_angle_horizontal":{"descr'
      + 'iption":"maximum inclination angle of horizontal plane patches [deg]",'
      + '"maximum":360.0,"minimum":-360.0,"type":"number"},"plane_classificatio'
      + 'n_method":{"description":"method ID (=1)","maximum":1,"minimum":1,"typ'
      + 'e":"integer"}},"required":["plane_classification_method","maximum_incl'
      + 'ination_angle_horizontal"],"type":"object"}},"$schema":"http://json-sc'
      + 'hema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"settings":{"sloping_plane_classes_minimum_angle":10.0,"sloping_plane'
      + '_classes_maximum_angle":70.0,"plane_classification_method":2},"classes'
      + '":{"13":"sloping, pointing down and west","12":"sloping, pointing down'
      + ' and north","6":"vertical, pointing east","11":"sloping, pointing down'
      + ' and south","1":"horizontal, pointing up","8":"vertical, pointing '
      + 'north","5":"sloping, pointing up and west","2":"sloping, pointing up '
      + 'and east","3":"sloping, pointing up and south","4":"sloping, pointing '
      + 'up and north","7":"vertical, pointing south","14":"horizontal, '
      + 'pointing down","10":"sloping, pointing down and east","9":"vertical, '
      + 'pointing west"}}'
    );
  );

// Grouping and sorting of point attributes for visualization purposes
const
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.point_attribute_groups';
    Title       : 'Point Attribute Groups';
    Description : 'Grouping and sorting of point attributes for visualization purposes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Grouping and sorting of point attributes for '
      + 'visualization purposes","additionalProperties":false,"type":"object","'
      + 'patternProperties":{"^.*$":{"description":"Each field of the object '
      + 'represents a point attribute group and holds a list of point '
      + 'attributes, where the field name is the group '
      + 'name.","items":{"description":"Point attribute full name or name '
      + 'pattern (perl regular expression '
      + 'syntax)","type":"string"},"minItems":1,"type":"array"}},"title":"Point'
      + ' Attribute '
      + 'Groups","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"Time":["riegl.timestamp"],"Secondary Attributes":["riegl.mirror_face'
      + 't","riegl.waveform_available"],"Coordinates/Vectors":["riegl.xyz","rie'
      + 'gl.range","riegl.theta","riegl.phi"],"Other '
      + 'Attributes":["riegl.selected","riegl.visible"],"Primary '
      + 'Attributes":["riegl.reflectance","riegl.amplitude","riegl.deviation"]}'
    );
  );

// Details about point cloud files
const
  RDB_RIEGL_POINTCLOUD_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pointcloud_info';
    Title       : 'Point Cloud Information';
    Description : 'Details about point cloud files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about point cloud files","properties":{"commen'
      + 'ts":{"description":"Comments","type":"string"},"field_of_application":'
      + '{"description":"Field of application","enum":["unknown","SLS","TLS","K'
      + 'LS","MLS","ULS","ALS","BLS","ILS"],"type":"string"},"project":{"descri'
      + 'ption":"Project name","type":"string"}},"type":"object","title":"Point'
      + ' Cloud '
      + 'Information","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"comments":"Line 3","field_of_application":"ALS","project":"Campaign '
      + '4"}'
    );
  );

// Estimated position and orientation information
const
  RDB_RIEGL_POSE_ESTIMATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pose_estimation';
    Title       : 'Pose Estimation';
    Description : 'Estimated position and orientation information';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Estimated position and orientation information as '
      + 'measured by GNSS, IMU or inclination sensors","required":["orientation'
      + '"],"type":"object","properties":{"orientation":{"description":"Orienta'
      + 'tion values and orientation accuracies, measured with IMU or '
      + 'inclination sensors.","properties":{"roll":{"description":"Roll angle '
      + 'about scanner X-axis [deg]","maximum":360,"minimum":-360,"type":"numbe'
      + 'r"},"roll_accuracy":{"description":"Roll angle accuracy [deg]","exclus'
      + 'iveMinimum":true,"minimum":0,"type":"number"},"yaw":{"description":"Ya'
      + 'w angle about scanner Z-axis [deg]","maximum":360,"minimum":-360,"type'
      + '":"number"},"pitch_accuracy":{"description":"Pitch angle accuracy [deg'
      + ']","exclusiveMinimum":true,"minimum":0,"type":"number"},"yaw_accuracy"'
      + ':{"description":"Yaw angle accuracy [deg]","exclusiveMinimum":true,"mi'
      + 'nimum":0,"type":"number"},"pitch":{"description":"Pitch angle about '
      + 'scanner Y-axis [deg]","maximum":360,"minimum":-360,"type":"number"}},"'
      + 'required":["roll","pitch","yaw","roll_accuracy","pitch_accuracy","yaw_'
      + 'accuracy"],"type":"object"},"barometric_height_amsl":{"description":"A'
      + 'ltitude determined based on the atmospheric pressure according to the '
      + 'standard atmosphere laws '
      + '[m].","type":"number"},"position":{"description":"Position coordinates'
      + ' and position accuracy values as measured by GNSS in the specified '
      + 'Coordinate Reference System '
      + '(CRS)","properties":{"coordinate_2":{"description":"Coordinate 2 as '
      + 'defined by axis 2 of the specified CRS (e.g., Y, Longitude)","type":"n'
      + 'umber"},"horizontal_accuracy":{"description":"Horizontal accuracy [m]"'
      + ',"exclusiveMinimum":true,"minimum":0,"type":"number"},"crs":{"descript'
      + 'ion":"Global Coordinate Reference '
      + 'System","properties":{"wkt":{"description":"\"Well-Known Text\" '
      + 'string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w'
      + 'kt-crs)","type":"string"},"epsg":{"description":"EPSG code","minimum":'
      + '0,"type":"integer"}},"required":["epsg"],"type":"object"},"coordinate_'
      + '1":{"description":"Coordinate 1 as defined by axis 1 of the specified '
      + 'CRS (e.g., X, Latitude)","type":"number"},"vertical_accuracy":{"descri'
      + 'ption":"Vertical accuracy [m]","exclusiveMinimum":true,"minimum":0,"ty'
      + 'pe":"number"},"coordinate_3":{"description":"Coordinate 3 as defined '
      + 'by axis 3 of the specified CRS (e.g., Z, Altitude)","type":"number"}},'
      + '"required":["coordinate_1","coordinate_2","coordinate_3","horizontal_a'
      + 'ccuracy","vertical_accuracy","crs"],"type":"object"}},"title":"Pose '
      + 'Estimation","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"orientation":{"roll":3.14743073066123,"roll_accuracy":0.009433783936'
      + '875745,"yaw":101.87293630292045,"pitch_accuracy":0.009433783936875745,'
      + '"yaw_accuracy":1.0094337839368757,"pitch":1.509153024827064},"barometr'
      + 'ic_height_amsl":386.7457796227932,"position":{"coordinate_2":15.645033'
      + '406,"horizontal_accuracy":0.810699999332428,"crs":{"wkt":"GEOGCS[\"WGS'
      + '84 / Geographic\",DATUM[\"WGS84\",SPHEROID[\"WGS84\",6378137.000,298.2'
      + '57223563,AUTHORITY[\"EPSG\",\"7030\"]],AUTHORITY[\"EPSG\",\"6326\"]],P'
      + 'RIMEM[\"Greenwich\",0.0000000000000000,AUTHORITY[\"EPSG\",\"8901\"]],U'
      + 'NIT[\"Degree\",0.01745329251994329547,AUTHORITY[\"EPSG\",\"9102\"]],AX'
      + 'IS[\"Latitude\",NORTH],AXIS[\"Longitude\",EAST],AUTHORITY[\"EPSG\",\"4'
      + '979\"]]","epsg":4979},"coordinate_1":48.655799473,"vertical_accuracy":'
      + '1.3314999341964722,"coordinate_3":362.7124938964844}}'
    );
  );

// Details on position and orientation sensors
const
  RDB_RIEGL_POSE_SENSORS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pose_sensors';
    Title       : 'Pose Sensors';
    Description : 'Details on position and orientation sensors';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details on position and orientation sensors","required'
      + '":["gyroscope","accelerometer","magnetic_field_sensor"],"type":"object'
      + '","properties":{"magnetic_field_sensor":{"description":"Magnetic Field'
      + ' Sensor details","properties":{"offset":{"$ref":"#/definitions/vector"'
      + ',"description":"Value to be subtracted from raw measurement values"},"'
      + 'z_axis":{"$ref":"#/definitions/vector","description":"Sensitive Z axis'
      + ' of sensor at frame angle = 0"},"relative_nonlinearity":{"$ref":"#/def'
      + 'initions/vector","description":"Relative nonlinearity, '
      + 'dimensionless"},"unit":{"description":"Unit of raw data and '
      + 'calibration values, 1 LSB in nT","exclusiveMinimum":true,"minimum":0,"'
      + 'type":"number"},"x_axis":{"$ref":"#/definitions/vector","description":'
      + '"Sensitive X axis of sensor at frame angle = '
      + '0"},"fixed":{"$ref":"#/definitions/vector","description":"Distortion '
      + 'of magnetic field caused by non-rotating scanner part"},"y_axis":{"$re'
      + 'f":"#/definitions/vector","description":"Sensitive Y axis of sensor at'
      + ' frame angle = 0"}},"required":["unit","x_axis","y_axis","z_axis","off'
      + 'set","fixed","relative_nonlinearity"],"type":"object"},"accelerometer"'
      + ':{"description":"Accelerometer details","properties":{"offset":{"$ref"'
      + ':"#/definitions/vector","description":"Value to be subtracted from raw'
      + ' measurement values"},"z_axis":{"$ref":"#/definitions/vector","descrip'
      + 'tion":"Sensitive Z axis of sensor at frame angle = 0"},"relative_nonli'
      + 'nearity":{"$ref":"#/definitions/vector","description":"Relative '
      + 'nonlinearity, dimensionless"},"unit":{"description":"Unit of raw data '
      + 'and calibration values, 1 LSB in 9.81 m/s\u00b2","exclusiveMinimum":tr'
      + 'ue,"minimum":0,"type":"number"},"x_axis":{"$ref":"#/definitions/vector'
      + '","description":"Sensitive X axis of sensor at frame angle = '
      + '0"},"origin":{"$ref":"#/definitions/vector","description":"Sensor '
      + 'origin in SOCS [m] at frame angle = '
      + '0"},"y_axis":{"$ref":"#/definitions/vector","description":"Sensitive Y'
      + ' axis of sensor at frame angle = 0"}},"required":["unit","x_axis","y_a'
      + 'xis","z_axis","offset","origin","relative_nonlinearity"],"type":"objec'
      + 't"},"gyroscope":{"description":"Gyroscope details","properties":{"offs'
      + 'et":{"$ref":"#/definitions/vector","description":"Value to be '
      + 'subtracted from raw measurement values"},"z_axis":{"$ref":"#/definitio'
      + 'ns/vector","description":"Sensitive Z axis of sensor at frame angle = '
      + '0"},"relative_nonlinearity":{"$ref":"#/definitions/vector","descriptio'
      + 'n":"Relative nonlinearity, dimensionless"},"unit":{"description":"Unit'
      + ' of raw data and calibration values, 1 LSB in rad/s","exclusiveMinimum'
      + '":true,"minimum":0,"type":"number"},"x_axis":{"$ref":"#/definitions/ve'
      + 'ctor","description":"Sensitive X axis of sensor at frame angle = '
      + '0"},"origin":{"$ref":"#/definitions/vector","description":"Sensor '
      + 'origin in SOCS [m] at frame angle = '
      + '0"},"y_axis":{"$ref":"#/definitions/vector","description":"Sensitive Y'
      + ' axis of sensor at frame angle = 0"}},"required":["unit","x_axis","y_a'
      + 'xis","z_axis","offset","origin","relative_nonlinearity"],"type":"objec'
      + 't"}},"title":"Pose '
      + 'Sensors","definitions":{"vector":{"items":{"description":"Index 0=X, '
      + '1=Y, 2=Z component","type":"number"},"minItems":3,"maxItems":3,"type":'
      + '"array"}},"$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"magnetic_field_sensor":{"offset":[-23812.052734375,5606.57666015625,'
      + '2493.28125],"z_axis":[0.00041987866279669106,7.876977906562388e-05,0.0'
      + '11407104320824146],"relative_nonlinearity":[0.0,0.0,0.0],"unit":91.743'
      + '11828613281,"x_axis":[-0.011162743903696537,-2.315962774446234e-05,0.0'
      + '0016818844596855342],"fixed":[-1576.010498046875,1596.081787109375,0.0'
      + '],"y_axis":[0.00027888521435670555,-0.011427424848079681,-5.2048297220'
      + '60822e-05]},"accelerometer":{"offset":[-733.3636474609375,58.969032287'
      + '597656,1060.2550048828125],"z_axis":[1.639882206916809,15166.744140625'
      + ',-116.99742889404297],"relative_nonlinearity":[0.0,0.0,0.0],"unit":6.6'
      + '66666740784422e-05,"x_axis":[-15008.123046875,56.956390380859375,-60.5'
      + '175666809082],"origin":[0.026900000870227814,-0.03999999910593033,-0.0'
      + '8950000256299973],"y_axis":[-7.027288913726807,-44.12333679199219,1495'
      + '2.3701171875]},"gyroscope":{"offset":[-50.92609786987305,146.156433105'
      + '46875,62.4327278137207],"z_axis":[0.555869996547699,119.22135162353516'
      + ',0.467585027217865],"relative_nonlinearity":[2.888176311444113e-07,1.0'
      + '6274164579645e-07,-1.7186295080634935e-39],"unit":0.000145444108056835'
      + '83,"x_axis":[-121.195556640625,0.8219714164733887,0.2313031703233719],'
      + '"origin":[0.026900000870227814,-0.03999999910593033,-0.089500002562999'
      + '73],"y_axis":[-0.440765917301178,-0.7897399663925171,119.5894775390625'
      + ']}}'
    );
  );

// Laser pulse position modulation used for MTA resolution
const
  RDB_RIEGL_PULSE_POSITION_MODULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pulse_position_modulation';
    Title       : 'Pulse Position Modulation';
    Description : 'Laser pulse position modulation used for MTA resolution';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Laser pulse position modulation used for MTA resolutio'
      + 'n","required":["length","num_mod_ampl","pulse_interval"],"type":"objec'
      + 't","properties":{"num_mod_ampl":{"description":"Number of different '
      + 'modulation amplitudes (2: binary modulation)","maximum":255,"minimum":'
      + '0,"type":"integer"},"pulse_interval":{"description":"Explicit table of'
      + ' the pulse position modulation used for MTA resolution. Table gives '
      + 'times between successive laser pulses in seconds.","items":{"minimum":'
      + '0,"type":"number"},"type":"array"},"phase_step":{"description":"Step '
      + 'width in phase of modulation code from line to line","maximum":255,"mi'
      + 'nimum":0,"type":"integer"},"code_phase_mode":{"description":"0: no '
      + 'synchronization, 1: toggle between 2 phases, 2: increment with phase_i'
      + 'ncrement","maximum":255,"minimum":0,"type":"integer"},"length":{"descr'
      + 'iption":"Length of '
      + 'code","maximum":255,"minimum":0,"type":"integer"}},"title":"Pulse '
      + 'Position '
      + 'Modulation","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"num_mod_ampl":2,"pulse_interval":[2.759375e-06,2.759375e-06,2.759375'
      + 'e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.821875e-06,'
      + '2.759375e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.821'
      + '875e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.759375e-'
      + '06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.'
      + '821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.75937'
      + '5e-06,2.821875e-06],"phase_step":5,"code_phase_mode":2,"length":31}'
    );
  );

// Statistics about target distance wrt. SOCS origin
const
  RDB_RIEGL_RANGE_STATISTICS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.range_statistics';
    Title       : 'Range Statistics';
    Description : 'Statistics about target distance wrt. SOCS origin';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Statistics about target distance wrt. SOCS origin","re'
      + 'quired":["minimum","average","maximum","std_dev"],"type":"object","pro'
      + 'perties":{"maximum":{"description":"Maximum '
      + 'value","type":"number"},"std_dev":{"description":"Standard '
      + 'deviation","type":"number"},"average":{"description":"Average '
      + 'value","type":"number"},"minimum":{"description":"Minimum '
      + 'value","type":"number"}},"title":"Range '
      + 'Statistics","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"maximum":574.35,"std_dev":24.349,"average":15.49738,"minimum":0.919}'
    );
  );

// Receiver Internals
const
  RDB_RIEGL_RECEIVER_INTERNALS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.receiver_internals';
    Title       : 'Receiver Internals';
    Description : 'Receiver Internals';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Receiver Internals","type":"object","properties":{"nt"'
      + ':{"maximum":255,"description":"Number of traces","minimum":0,"type":"i'
      + 'nteger"},"ns":{"maximum":4095,"description":"Number of samples","minim'
      + 'um":0,"type":"integer"},"ex":{"description":"DEPRECATED, use '
      + '''riegl.exponential_decomposition'' instead","type":"object"},"t":{"addi'
      + 'tionalProperties":false,"patternProperties":{"^[0-9]+$":{"description"'
      + ':"one field per channel, field name is channel index","$ref":"#/defini'
      + 'tions/fp"}},"type":"object"},"sr":{"description":"Sample rate [Hz]","e'
      + 'xclusiveMinimum":true,"minimum":0,"type":"number"},"mw":{"maximum":409'
      + '5,"description":"Maximum weight","exclusiveMinimum":true,"minimum":0,"'
      + 'type":"number"},"si":{"maximum":255,"description":"Start index '
      + '(hw_start)","minimum":0,"type":"number"},"tbl":{"description":"various'
      + ' internal data","items":{"$ref":"#/definitions/fp_table"},"minItems":1'
      + ',"type":"array"},"a":{"description":"Amplitude [dB]","items":{"type":"'
      + 'number"},"minItems":1,"maxItems":256,"type":"array"}},"title":"Receive'
      + 'r Internals","definitions":{"fp_table_row":{"items":{"type":"number"},'
      + '"minItems":1,"maxItems":2048,"type":"array"},"fp":{"description":"Fing'
      + 'erprint values","properties":{"w":{"items":{"items":{"type":"number"},'
      + '"minItems":5,"maxItems":5,"type":"array"},"minItems":1,"maxItems":256,'
      + '"type":"array"},"s":{"items":{"items":{"type":"number"},"minItems":1,"'
      + 'maxItems":4096,"type":"array"},"minItems":1,"maxItems":256,"type":"arr'
      + 'ay"}},"required":["s","w"],"type":"object"},"fp_table":{"properties":{'
      + '"ny":{"description":"number of y entries","max":2048,"min":1,"type":"i'
      + 'nteger"},"nx":{"description":"number of x entries","max":2048,"min":1,'
      + '"type":"integer"},"tv":{"items":{"oneOf":[{"$ref":"#/definitions/fp_ta'
      + 'ble_row"},{"type":"number"}]},"minItems":1,"maxItems":2048,"type":"arr'
      + 'ay"},"tc":{"description":"table data type '
      + 'code","max":255,"min":0,"type":"integer"},"ch":{"description":"channel'
      + ' number","max":255,"min":0,"type":"integer"}},"required":["ch","tc","n'
      + 'x","ny","tv"],"desription":"scanner internal data","type":"object"}},"'
      + '$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"nt":128,"ns":400,"tbl":[{"ny":2,"nx":5,"tv":[[1,2,3,4,5],[1.1,2.2,3.'
      + '3,4.4,5.5]],"tc":1,"ch":0}],"t":{"0":{"w":[[78,86,126,134,31],[78,86,1'
      + '26,134,31]],"s":[[1.23,4.56],[7.89,0.12]]},"1":{"w":[[78,86,126,134,31'
      + '],[78,86,126,134,31]],"s":[[1.23,4.56],[7.89,0.12]]}},"sr":7959997000.'
      + '0,"mw":31,"si":48,"a":[-1.55]}'
    );
  );

// List of names of the records
const
  RDB_RIEGL_RECORD_NAMES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.record_names';
    Title       : 'Record Names';
    Description : 'List of names of the records';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"List of names of the '
      + 'records","properties":{"names":{"description":"List of record names. '
      + 'The name of a record is the {riegl.id}th element of this list. The '
      + 'number of elements must correspond to the maximum riegl.id occurring '
      + 'in this file.","items":{"description":"Record name","type":"string"},"'
      + 'type":"array"}},"type":"object","title":"Record '
      + 'Names","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"names":["Name of first record","Name of second record","Name of '
      + 'third record","Name of fourth record"]}'
    );
  );

// Lookup table for reflectance calculation based on amplitude and range
const
  RDB_RIEGL_REFLECTANCE_CALCULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.reflectance_calculation';
    Title       : 'Reflectance Calculation Table';
    Description : 'Lookup table for reflectance calculation based on amplitude and range';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Lookup table for reflectance calculation based on '
      + 'amplitude and range","required":["delta","content"],"type":"object","p'
      + 'roperties":{"content":{"description":"Correction value [dB] to be '
      + 'added to the amplitude","items":{"type":"number"},"minItems":1,"maxIte'
      + 'ms":2000,"type":"array"},"delta":{"description":"Delta between table '
      + 'entries [m], first entry is at range = 0 '
      + 'm","type":"number"}},"title":"Reflectance Calculation '
      + 'Table","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"content":[-33.01],"delta":0.150918}'
    );
  );

// Range-dependent and scan-angle-dependent correction of reflectance reading
const
  RDB_RIEGL_REFLECTANCE_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.reflectance_correction';
    Title       : 'Near-range reflectance correction';
    Description : 'Range-dependent and scan-angle-dependent correction of reflectance reading';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Range-dependent and scan-angle-dependent correction of'
      + ' reflectance reading","required":["ranges_m","line_angles_deg","reflec'
      + 'tance_correction_db"],"type":"object","properties":{"reflectance_corre'
      + 'ction_db":{"description":"Near range reflectance correction in dB as a'
      + ' function of range over angle","items":{"description":"rows (each '
      + 'array corresponds to a range)","items":{"description":"columns (each '
      + 'value corresponds to an angle)","type":"number"},"type":"array"},"type'
      + '":"array"},"ranges_m":{"description":"Range [m]","items":{"type":"numb'
      + 'er"},"type":"array"},"line_angles_deg":{"description":"Angle '
      + '[deg]","items":{"type":"number"},"type":"array"}},"title":"Near-range '
      + 'reflectance '
      + 'correction","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"reflectance_correction_db":[[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.'
      + '01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0'
      + '.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01]],"ra'
      + 'nges_m":[0.0,1.0,2.0,3.0],"line_angles_deg":[0.0,0.5,1.0,1.5,1.0,2.0,2'
      + '.5,3.0,3.5,4.0]}'
    );
  );

// Scan Pattern Description
const
  RDB_RIEGL_SCAN_PATTERN : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.scan_pattern';
    Title       : 'Scan Pattern';
    Description : 'Scan Pattern Description';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Scan Pattern '
      + 'Description","properties":{"rectangular":{"description":"Rectangular '
      + 'Field Of View Scan '
      + 'Pattern","properties":{"theta_start":{"description":"Start theta angle'
      + ' in SOCS [deg]","maximum":180.0,"minimum":0.0,"type":"number"},"phi_st'
      + 'op":{"description":"Stop phi angle in SOCS [deg]","maximum":720.0,"min'
      + 'imum":0.0,"type":"number"},"phi_increment":{"description":"Increment '
      + 'of phi angle in SOCS [deg]","maximum":90.0,"minimum":0.0,"type":"numbe'
      + 'r"},"theta_stop":{"description":"Stop theta angle in SOCS [deg]","maxi'
      + 'mum":180.0,"minimum":0.0,"type":"number"},"theta_increment":{"descript'
      + 'ion":"Increment of theta angle in SOCS [deg]","maximum":90.0,"minimum"'
      + ':0.0,"type":"number"},"phi_start":{"description":"Start phi angle in '
      + 'SOCS [deg]","maximum":360.0,"minimum":0.0,"type":"number"},"program":{'
      + '"$ref":"#/definitions/program"}},"required":["phi_start","phi_stop","p'
      + 'hi_increment","theta_start","theta_stop","theta_increment"],"type":"ob'
      + 'ject"},"segments":{"description":"Segmented Line Scan '
      + 'Pattern","properties":{"list":{"items":{"description":"Line Scan '
      + 'Segment","properties":{"stop":{"description":"Stop angle in SOCS [deg]'
      + '","maximum":720.0,"minimum":0.0,"type":"number"},"start":{"description'
      + '":"Start angle in SOCS [deg]","maximum":360.0,"minimum":0.0,"type":"nu'
      + 'mber"},"increment":{"description":"Increment of angle in SOCS [deg]","'
      + 'maximum":90.0,"minimum":0.0,"type":"number"}},"required":["start","sto'
      + 'p","increment"],"type":"object"},"type":"array"},"program":{"$ref":"#/'
      + 'definitions/program"}},"required":["list"],"type":"object"},"line":{"d'
      + 'escription":"Line Scan '
      + 'Pattern","properties":{"stop":{"description":"Stop angle in SOCS [deg]'
      + '","maximum":720.0,"minimum":0.0,"type":"number"},"start":{"description'
      + '":"Start angle in SOCS [deg]","maximum":360.0,"minimum":0.0,"type":"nu'
      + 'mber"},"increment":{"description":"Increment of angle in SOCS [deg]","'
      + 'maximum":90.0,"minimum":0.0,"type":"number"},"program":{"$ref":"#/defi'
      + 'nitions/program"}},"required":["start","stop","increment"],"type":"obj'
      + 'ect"}},"title":"Scan '
      + 'Pattern","definitions":{"program":{"description":"Measurement '
      + 'program","properties":{"name":{"description":"Name of measurement '
      + 'program","type":"string"},"laser_prr":{"description":"Laser Pulse '
      + 'Repetition Rate [Hz]","exclusiveMinimum":false,"minimum":0,"type":"num'
      + 'ber"}},"required":["name"],"type":"object"}},"$schema":"http://json-sc'
      + 'hema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"rectangular":{"theta_start":30.0,"phi_stop":270.0,"phi_increment":0.'
      + '04,"theta_stop":130.0,"theta_increment":0.04,"phi_start":45.0,"program'
      + '":{"name":"High Speed","laser_prr":100000.0}}}'
    );
  );

// Details about laser shot files
const
  RDB_RIEGL_SHOT_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.shot_info';
    Title       : 'Shot Information';
    Description : 'Details about laser shot files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about laser shot files","properties":{"shot_fi'
      + 'le":{"properties":{"file_uuid":{"description":"File''s Universally '
      + 'Unique Identifier (RFC '
      + '4122)","type":"string"},"file_extension":{"description":"Shot file '
      + 'extension, without the leading dot","type":"string"}},"required":["fil'
      + 'e_extension"],"type":"object"}},"type":"object","title":"Shot '
      + 'Information","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"shot_file":{"file_uuid":"26a00815-67c0-4bff-8fe8-c577378fe663","file'
      + '_extension":"sodx"}}'
    );
  );

// Conversion of background radiation raw values to temperatures in °C
const
  RDB_RIEGL_TEMPERATURE_CALCULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.temperature_calculation';
    Title       : 'Temperature Calculation Table';
    Description : 'Conversion of background radiation raw values to temperatures in °C';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Conversion of background radiation raw values to '
      + 'temperatures in \u00b0C","type":"object","properties":{"Si":{"$ref":"#'
      + '/definitions/conversion_table","description":"Conversion table for Si '
      + 'channel"},"InGaAs_Si_Difference":{"$ref":"#/definitions/conversion_tab'
      + 'le","description":"Conversion table for InGaAs - Si difference"},"InGa'
      + 'As":{"$ref":"#/definitions/conversion_table","description":"Conversion'
      + ' table for InGaAs channel"}},"title":"Temperature Calculation Table","'
      + 'definitions":{"conversion_table":{"properties":{"temperature":{"descri'
      + 'ption":"Temperature [\u00b0C]","items":{"type":"number"},"type":"array'
      + '"},"value":{"description":"LSB [1]","items":{"type":"number"},"type":"'
      + 'array"}},"required":["value","temperature"],"type":"object"}},"$schema'
      + '":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"Si":{"temperature":[546.300048828125,548.8164051212026,551.314393850'
      + '0972,554.0144257850053,556.604252334815,559.2124464488079,561.80227299'
      + '86177,564.4104671126105,567.0002936624203],"value":[0.0,64.00097659230'
      + '323,128.0019531846065,192.0029297769097,256.0039063692129,320.00488296'
      + '151616,384.0058595538194,448.0068361461226,512.0078127384259]},"InGaAs'
      + '_Si_Difference":{"temperature":[1749.977111117893,1749.977111117893,17'
      + '49.977111117893,1749.977111117893,1749.977111117893,1749.977111117893,'
      + '1744.7813348796044,1681.9971312601092,1622.3944822534868],"value":[100'
      + '0.0,1100.090029602954,1200.04425183874,1300.1342814416948,1400.0885036'
      + '774805,1500.0427259132668,1600.1327555162209,1700.0869777520065,1800.0'
      + '411999877924]},"InGaAs":{"temperature":[307.22196722535614,309.1153478'
      + '247277,311.1188086915047,313.10025350480055,315.2137946389828,317.2172'
      + '555057597,319.2207163725366,321.2021611858325,323.3157023200148],"valu'
      + 'e":[0.0,64.00097659230323,128.0019531846065,192.0029297769097,256.0039'
      + '063692129,320.00488296151616,384.0058595538194,448.0068361461226,512.0'
      + '078127384259]}}'
    );
  );

// Base of timestamps (epoch)
const
  RDB_RIEGL_TIME_BASE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.time_base';
    Title       : 'Time Base';
    Description : 'Base of timestamps (epoch)';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Base of timestamps (epoch)","required":["epoch","sourc'
      + 'e"],"type":"object","properties":{"system":{"description":"Time system'
      + ' (time standard)","enum":["unknown","UTC","GPS"],"type":"string"},"epo'
      + 'ch":{"description":"Date and time of timestamp ''0'' as proposed by RFC '
      + '3339 (e.g. 2015-10-27T00:00:00+01:00).","type":"string"},"source":{"de'
      + 'scription":"Timestamp source","enum":["unknown","RTC","GNSS"],"type":"'
      + 'string"}},"title":"Time '
      + 'Base","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"system":"UTC","epoch":"2015-10-27T00:00:00+00:00","source":"GNSS"}'
    );
  );

// Details about position+orientation files
const
  RDB_RIEGL_TRAJECTORY_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.trajectory_info';
    Title       : 'Trajectory Information';
    Description : 'Details about position+orientation files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about position+orientation files","required":['
      + '"time_interval","navigation_frame"],"type":"object","properties":{"com'
      + 'pany":{"description":"Company '
      + 'name","type":"string"},"software":{"description":"Software that '
      + 'calculated the trajectory (this may be the same or different software '
      + 'than the one that created the '
      + 'file)","type":"string"},"time_interval":{"description":"Time interval '
      + 'statistics","properties":{"maximum":{"description":"Maximum time '
      + 'interval [s]","type":"number"},"std_dev":{"description":"Standard '
      + 'deviation of intervals '
      + '[s]","type":"number"},"average":{"description":"Average time interval '
      + '[s]","type":"number"},"minimum":{"description":"Minimum time interval '
      + '[s]","type":"number"}},"required":["minimum","average","maximum","std_'
      + 'dev"],"type":"object"},"navigation_frame":{"description":"Navigation '
      + 'frame (NED: North-East-Down, ENU: East-North-Up)","enum":["unknown","N'
      + 'ED","ENU"],"type":"string"},"device":{"description":"Navigation '
      + 'device, e.g. name/type/serial","type":"string"},"field_of_application"'
      + ':{"description":"Field of application","enum":["unknown","SLS","TLS","'
      + 'KLS","MLS","ULS","ALS","BLS","ILS"],"type":"string"},"settings":{"desc'
      + 'ription":"Settings used to calculate the trajectory (descriptive '
      + 'text)","type":"string"},"location":{"description":"Project location, '
      + 'e.g. '
      + 'city/state/country","type":"string"},"project":{"description":"Project'
      + ' name","type":"string"}},"title":"Trajectory '
      + 'Information","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"company":"RIEGL LMS","software":"Navigation Software XYZ","time_inte'
      + 'rval":{"maximum":0.005004883,"std_dev":5.51e-07,"average":0.00500053,"'
      + 'minimum":0.00500032},"navigation_frame":"NED","device":"IMU Model '
      + '12/1, Serial# 12345","field_of_application":"MLS","settings":"default"'
      + ',"location":"Horn","project":"Campaign 3"}'
    );
  );

// Details about vertex file
const
  RDB_RIEGL_VERTEX_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.vertex_info';
    Title       : 'Vertex Information';
    Description : 'Details about vertex file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about vertex file","properties":{"vertex_file"'
      + ':{"properties":{"file_uuid":{"description":"File''s Universally Unique '
      + 'Identifier (RFC '
      + '4122)","type":"string"},"file_extension":{"description":"Vertex file '
      + 'extension, without the leading dot","type":"string"}},"required":["fil'
      + 'e_extension"],"type":"object"}},"type":"object","title":"Vertex '
      + 'Information","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"vertex_file":{"file_uuid":"51534d95-d71f-4f36-ae1a-3e63a21fd1c7","fi'
      + 'le_extension":"vtx"}}'
    );
  );

// Details about the voxels contained in the file
const
  RDB_RIEGL_VOXEL_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.voxel_info';
    Title       : 'Voxel Information';
    Description : 'Details about the voxels contained in the file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about the voxels contained in the file","type"'
      + ':"object","oneOf":[{"additionalProperties":false,"properties":{"voxel_'
      + 'origin":{"$ref":"#/definitions/voxel_origin_enum"},"voxel_type":{"$ref'
      + '":"#/definitions/voxel_type"},"size":{"description":"Size of voxels in'
      + ' file coordinate system.","oneOf":[{"$ref":"#/definitions/voxel_size"}'
      + ',{"$ref":"#/definitions/voxel_size_cubic"}]},"shape_thresholds":{"$ref'
      + '":"#/definitions/shape_thresholds"}},"required":["size","voxel_origin"'
      + ',"voxel_type"]},{"additionalProperties":false,"properties":{"voxel_typ'
      + 'e":{"$ref":"#/definitions/voxel_type"},"reference_point":{"description'
      + '":"Point in WGS84 geodetic decimal degree (EPSG:4326) that was used to'
      + ' compute the projection distortion parameters. The coefficient order '
      + 'is latitude, longitude. Only voxels with corresponding geo_tag, '
      + 'voxel_size and reference_point can be reliably processed together. '
      + 'This entry is available for voxel files in projected CRS only.","type"'
      + ':"array","minItems":2,"maxItems":2,"items":{"maximum":180,"minimum":-1'
      + '80,"type":"number"}},"size_llcs":{"$ref":"#/definitions/voxel_size","d'
      + 'escription":"Size of voxels in a locally levelled cartesian coordinate'
      + ' system (xyz). This is only used for voxels based on a map projection.'
      + '"},"voxel_origin":{"oneOf":[{"$ref":"#/definitions/voxel_origin_enum"}'
      + ',{"description":"The base point of the voxel grid. Used together with '
      + '<tt>voxel_size</tt> and <tt>voxel_index</tt> to compute actual point c'
      + 'oordinates.","$ref":"#/definitions/voxel_origin_point"}]},"size":{"$re'
      + 'f":"#/definitions/voxel_size","description":"Size of voxels in file '
      + 'coordinate system."},"shape_thresholds":{"$ref":"#/definitions/shape_t'
      + 'hresholds"}},"required":["reference_point","size_llcs","size","voxel_o'
      + 'rigin","voxel_type"]}],"title":"Voxel Information","definitions":{"vox'
      + 'el_size_cubic":{"$ref":"#/definitions/edge_length","type":"number"},"v'
      + 'oxel_origin_enum":{"description":"Defines whether the voxel''s center '
      + 'or a corner is placed on CRS origin <tt>(0/0/0)</tt>.","default":"corn'
      + 'er","enum":["center","corner"]},"edge_length":{"description":"Length '
      + 'of voxel edge [m].","exclusiveMinimum":true,"minimum":0,"type":"number'
      + '"},"voxel_size":{"description":"Size of voxels.","type":"array","minIt'
      + 'ems":3,"maxItems":3,"items":{"$ref":"#/definitions/edge_length"}},"vox'
      + 'el_type":{"description":"Whether a point in a voxel represents its '
      + 'center or its centroid. If type is <tt>index</tt> there is no point '
      + 'but only an integer voxel index.","default":"centroid","enum":["center'
      + '","centroid","index"]},"voxel_origin_point":{"description":"Origin '
      + 'point for all voxel indices in voxel CRS.","type":"array","minItems":3'
      + ',"maxItems":3,"items":{"type":"number"}},"shape_thresholds":{"descript'
      + 'ion":"Thresholds used to compute the voxel''s shape_id '
      + 'value.","properties":{"plane":{"description":"If the smallest '
      + 'eigenvalue is smaller than the median eigenvalue * plane_threshold, '
      + 'the voxel is considered a plane.","maximum":1,"type":"number","exclusi'
      + 'veMaximum":true,"exclusiveMinimum":true,"minimum":0},"line":{"descript'
      + 'ion":"If the biggest eigenvalue is bigger than the median eigenvalue *'
      + ' line_threshold, the voxel is considered a line.","exclusiveMinimum":t'
      + 'rue,"minimum":1,"type":"number"}},"required":["plane","line"],"type":"'
      + 'object"}},"$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"voxel_type":"centroid","reference_point":[48,16],"size_llcs":[0.5156'
      + '575252891171,0.5130835356683303,0.5143705304787237],"voxel_origin":"co'
      + 'rner","size":[0.5971642834779395,0.5971642834779395,0.5143705304787237'
      + '],"shape_thresholds":{"line":6,"plane":0.16}}'
    );
  );

// Settings for waveform averaging
const
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_averaging_settings';
    Title       : 'Waveform Averaging Settings';
    Description : 'Settings for waveform averaging';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Settings for waveform averaging","required":["num_shot'
      + 's","mta_zone"],"type":"object","properties":{"num_shots":{"description'
      + '":"Number of consecutive shots to be used for averaging.","minimum":1,'
      + '"type":"integer"},"mta_zone":{"description":"Fixed MTA zone for averag'
      + 'ing.","minimum":1,"type":"integer"},"trim":{"description":"Percentage '
      + 'for robust averaging.","maximum":0.5,"default":0,"minimum":0,"type":"n'
      + 'umber"}},"title":"Waveform Averaging '
      + 'Settings","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"num_shots":7,"mta_zone":1,"trim":0.05}'
    );
  );

// Details about waveform files
const
  RDB_RIEGL_WAVEFORM_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_info';
    Title       : 'Waveform Information';
    Description : 'Details about waveform files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Details about waveform files","required":["sample_bloc'
      + 'k_file","sample_data_files"],"type":"object","properties":{"sample_dat'
      + 'a_files":{"items":{"properties":{"channel":{"maximum":255,"description'
      + '":"Sample block channel number (255 = invalid)","type":"integer","excl'
      + 'usiveMaximum":false,"exclusiveMinimum":false,"minimum":0},"file_uuid":'
      + '{"description":"File''s Universally Unique Identifier (RFC '
      + '4122)","type":"string"},"sample_interval":{"description":"Sampling '
      + 'interval in seconds","exclusiveMinimum":false,"minimum":0,"type":"numb'
      + 'er"},"channel_name":{"description":"Sample block channel name","type":'
      + '"string"},"delta_st":{"description":"reserved","type":"number"},"laser'
      + '_wavelength":{"description":"Laser wavelength in meters (0 = unknown)"'
      + ',"exclusiveMinimum":false,"minimum":0,"type":"number"},"sample_bits":{'
      + '"maximum":32,"description":"Bitwidth of samples (e.g. 10 bit, 12 bit)"'
      + ',"type":"integer","exclusiveMaximum":false,"exclusiveMinimum":false,"m'
      + 'inimum":0},"file_extension":{"description":"Sample data file '
      + 'extension, without the leading dot","type":"string"}},"required":["cha'
      + 'nnel","channel_name","sample_interval","sample_bits","laser_wavelength'
      + '","delta_st","file_extension"],"type":"object"},"type":"array"},"sampl'
      + 'e_block_file":{"properties":{"file_uuid":{"description":"File''s '
      + 'Universally Unique Identifier (RFC '
      + '4122)","type":"string"},"file_extension":{"description":"Sample block '
      + 'file extension, without the leading dot","type":"string"}},"required":'
      + '["file_extension"],"type":"object"},"range_offset_m":{"description":"C'
      + 'alibrated device specific waveform data range offset in '
      + 'meters.","type":"number"}},"title":"Waveform '
      + 'Information","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"sample_data_files":[{"channel":0,"file_uuid":"da084413-e3e8-4655-a12'
      + '2-071de8490d8e","sample_interval":1.00503e-09,"channel_name":"high_pow'
      + 'er","delta_st":0,"laser_wavelength":0,"sample_bits":12,"file_extension'
      + '":"sp0"},{"channel":1,"file_uuid":"93585b5e-5ea9-43a1-947b-e7ba3be642d'
      + '2","sample_interval":1.00503e-09,"channel_name":"low_power","delta_st"'
      + ':0,"laser_wavelength":0,"sample_bits":12,"file_extension":"sp1"},{"cha'
      + 'nnel":5,"file_uuid":"9d2298c4-1036-464f-b5cb-1cf8e517f3a0","sample_int'
      + 'erval":1.00503e-09,"channel_name":"wwf","delta_st":0,"laser_wavelength'
      + '":0,"sample_bits":12,"file_extension":"sp5"}],"sample_block_file":{"fi'
      + 'le_uuid":"93a03615-66c0-4bea-8ff8-c577378fe660","file_extension":"sbx"'
      + '},"range_offset_m":3.1415}'
    );
  );

// Scanner settings for waveform output
const
  RDB_RIEGL_WAVEFORM_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_settings';
    Title       : 'Waveform Settings';
    Description : 'Scanner settings for waveform output';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Scanner settings for waveform output","items":{"proper'
      + 'ties":{"pass_rng_greater":{"description":"Threshold for range greater '
      + 'than [m]","type":"number"},"logic_expression":{"description":"Logic '
      + 'expression of smart waveforms '
      + 'filter","type":"string"},"pass_dev_greater":{"description":"Threshold '
      + 'for deviation greater than '
      + '[1]","type":"integer"},"pass_dev_less":{"description":"Threshold for '
      + 'deviation less than '
      + '[1]","type":"integer"},"sbl_name":{"description":"Name of sample '
      + 'block, e.g.: wfm, '
      + 'wwf","type":"string"},"pass_rng_less":{"description":"Threshold for '
      + 'range less than '
      + '[m]","type":"number"},"enabled":{"description":"Waveform output '
      + 'enabled","type":"boolean"},"smart_enabled":{"description":"Smart '
      + 'waveform output enabled","type":"boolean"},"pass_ampl_greater":{"descr'
      + 'iption":"Threshold for amplitude greater than '
      + '[dB]","type":"number"},"channel_idx_mask":{"description":"Bit mask for'
      + ' channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = '
      + 'Bit1, '
      + '...","type":"integer"},"pass_ampl_less":{"description":"Threshold for '
      + 'amplitude less than [dB]","type":"number"}},"required":["sbl_name","en'
      + 'abled","channel_idx_mask"],"type":"object"},"type":"array","title":"Wa'
      + 'veform Settings","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '[{"pass_rng_greater":9.27,"sbl_name":"wfm","pass_rng_less":13.11,"enab'
      + 'led":true,"smart_enabled":true,"pass_ampl_greater":1.0,"channel_idx_ma'
      + 'sk":11,"pass_ampl_less":5.0},{"enabled":false,"channel_idx_mask":32,"s'
      + 'bl_name":"wwf"}]'
    );
  );

// Window analysis data estimated from scandata and resulting filter parameters
const
  RDB_RIEGL_WINDOW_ANALYSIS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.window_analysis';
    Title       : 'Window Analysis';
    Description : 'Window analysis data estimated from scandata and resulting filter parameters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Window analysis data estimated from scandata and '
      + 'resulting filter parameters","required":["result","filter","settings"]'
      + ',"type":"object","properties":{"filter":{"properties":{"amplitude_max"'
      + ':{"description":"[dB]","items":{"type":"number"},"type":"array"},"angl'
      + 'e":{"description":"[deg]","items":{"type":"number"},"type":"array"},"r'
      + 'ange_min":{"description":"[m]","items":{"type":"number"},"type":"array'
      + '"},"range_max":{"description":"[m]","items":{"type":"number"},"type":"'
      + 'array"}},"required":["angle","range_min","range_max","amplitude_max"],'
      + '"type":"object"},"result":{"properties":{"range_sigma":{"description":'
      + '"[m]","items":{"type":"number"},"type":"array"},"amplitude_sigma":{"de'
      + 'scription":"[dB]","items":{"type":"number"},"type":"array"},"amplitude'
      + '_mean":{"description":"[dB]","items":{"type":"number"},"type":"array"}'
      + ',"amplitude_offset":{"description":"[dB]","items":{"type":"number"},"t'
      + 'ype":"array"},"angle":{"description":"[deg]","items":{"type":"number"}'
      + ',"type":"array"},"range_mean":{"description":"[m]","items":{"type":"nu'
      + 'mber"},"type":"array"},"timestamp":{"description":"[s]","items":{"type'
      + '":"number"},"type":"array"}},"required":["angle","range_mean","range_s'
      + 'igma","amplitude_mean","amplitude_sigma","amplitude_offset"],"type":"o'
      + 'bject"},"settings":{"properties":{"range":{"properties":{"sigma_factor'
      + '":{"type":"number"},"additive_value":{"type":"number"}},"required":["s'
      + 'igma_factor","additive_value"],"type":"object"},"amplitude":{"properti'
      + 'es":{"sigma_factor":{"type":"number"},"additive_value":{"type":"number'
      + '"}},"required":["sigma_factor","additive_value"],"type":"object"}},"re'
      + 'quired":["range","amplitude"],"type":"object"}},"title":"Window '
      + 'Analysis","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"filter":{"amplitude_max":[8.04,8.01,7.99,7.96,7.93,7.9,7.88,7.85,7.8'
      + '3,7.8,7.78],"angle":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8'
      + ',15.9],"range_min":[-0.208,-0.21,-0.212,-0.214,-0.216,-0.218,-0.219,-0'
      + '.221,-0.223,-0.225,-0.227],"range_max":[0.424,0.425,0.426,0.427,0.428,'
      + '0.428,0.429,0.43,0.431,0.431,0.432]},"result":{"range_sigma":[0.018696'
      + '52,0.02151435,0.01747969,0.01918765,0.01945776,0.01934862,0.01955329,0'
      + '.02225589,0.02229977,0.01899122,0.02009433],"amplitude_sigma":[0.42728'
      + '44,0.4298479,0.4236816,0.4283583,0.4362353,0.4315141,0.4373984,0.44727'
      + '98,0.4346001,0.4345487,0.4540681],"amplitude_mean":[5.347396,5.263155,'
      + '5.224655,5.179926,5.097782,5.116479,5.051756,4.983473,5.007885,5.00244'
      + '1,4.982],"amplitude_offset":[1.9,1.9],"angle":[14.9,15.0,15.1,15.2,15.'
      + '3,15.4,15.5,15.6,15.7,15.8,15.9],"range_mean":[0.1105621,0.1079564,0.1'
      + '087088,0.1067261,0.1054582,0.1090412,0.102871,0.1019044,0.1051523,0.10'
      + '58445,0.1031261],"timestamp":[408.4441,411.4443]},"settings":{"range":'
      + '{"sigma_factor":8,"additive_value":0.1},"amplitude":{"sigma_factor":4,'
      + '"additive_value":1.0}}}'
    );
  );

// Correction parameters for window glass echoes
const
  RDB_RIEGL_WINDOW_ECHO_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.window_echo_correction';
    Title       : 'Window Echo Correction';
    Description : 'Correction parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"description":"Correction parameters for window glass echoes","requir'
      + 'ed":["amplitude","range","slices"],"type":"object","properties":{"slic'
      + 'es":{"items":{"description":"Window echo correction parameter '
      + 'slice","properties":{"amplitude":{"description":"Window echo amplitude'
      + ' of slice in dB","type":"number"},"table":{"description":"Correction '
      + 'table (dimension defined by the ''amplitude'' and ''range'' '
      + 'objects)","items":{"description":"Table row (= amplitude '
      + 'axis)","items":{"description":"Table column (= range '
      + 'axis)","items":{"description":"Table cell (item 0: amplitude in dB, 1:'
      + ' range in m, 2: flags)","type":"number"},"minItems":3,"maxItems":3,"ty'
      + 'pe":"array"},"minItems":1,"type":"array"},"minItems":1,"type":"array"}'
      + '},"required":["amplitude","table"],"type":"object"},"type":"array"},"a'
      + 'mplitude":{"description":"Amplitude axis of correction '
      + 'table","properties":{"maximum":{"description":"Maximum amplitude in '
      + 'dB","minimum":0.0,"type":"number"},"entries":{"description":"Number of'
      + ' amplitude entries","minimum":1,"type":"integer"},"minimum":{"descript'
      + 'ion":"Minimum amplitude in dB","minimum":0.0,"type":"number"}},"requir'
      + 'ed":["minimum","maximum","entries"],"type":"object"},"range":{"descrip'
      + 'tion":"Range axis of correction '
      + 'table","properties":{"maximum":{"description":"Maximum range in m","ma'
      + 'ximum":2.0,"minimum":-2.0,"type":"number"},"entries":{"description":"N'
      + 'umber of range entries","minimum":1,"type":"integer"},"minimum":{"desc'
      + 'ription":"Minimum range in m","maximum":2.0,"minimum":-2.0,"type":"num'
      + 'ber"}},"required":["minimum","maximum","entries"],"type":"object"}},"t'
      + 'itle":"Window Echo '
      + 'Correction","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"slices":[{"amplitude":1.5,"table":[[[6.23,0.3535,1]],[[5.54,0.72375,'
      + '1]]]},{"amplitude":2.0,"table":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]]}'
      + '],"amplitude":{"maximum":20,"entries":128,"minimum":2},"range":{"maxim'
      + 'um":1.5060822940732335,"entries":128,"minimum":-1.5060822940732335}}'
    );
  );

// Table of all meta data item details records
const
  RDB_META_DATA_ITEMS : array of PRDBPointcloudMetaDataItemInfo = nil; // filled during initialization

implementation

procedure FixStringEncoding;
begin
  // As the unit (.pas file) doesn't contain a BOM, we need to convert all strings
  // from UTF-8 to "native" encoding at runtime (tested on Delphi 7 and Delphi XE5)

  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Name)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Title)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Description)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Schema)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Example)));

  RDB_RIEGL_ATMOSPHERE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Name)));
  RDB_RIEGL_ATMOSPHERE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Title)));
  RDB_RIEGL_ATMOSPHERE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Description)));
  RDB_RIEGL_ATMOSPHERE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Schema)));
  RDB_RIEGL_ATMOSPHERE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Example)));

  RDB_RIEGL_BEAM_GEOMETRY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Name)));
  RDB_RIEGL_BEAM_GEOMETRY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Title)));
  RDB_RIEGL_BEAM_GEOMETRY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Description)));
  RDB_RIEGL_BEAM_GEOMETRY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Schema)));
  RDB_RIEGL_BEAM_GEOMETRY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Example)));

  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Name)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Title)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Description)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Schema)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Example)));

  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Name)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Title)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Description)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Schema)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Example)));

  RDB_RIEGL_DETECTION_PROBABILITY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Name)));
  RDB_RIEGL_DETECTION_PROBABILITY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Title)));
  RDB_RIEGL_DETECTION_PROBABILITY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Description)));
  RDB_RIEGL_DETECTION_PROBABILITY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Schema)));
  RDB_RIEGL_DETECTION_PROBABILITY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Example)));

  RDB_RIEGL_DEVICE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Name)));
  RDB_RIEGL_DEVICE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Title)));
  RDB_RIEGL_DEVICE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Description)));
  RDB_RIEGL_DEVICE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Schema)));
  RDB_RIEGL_DEVICE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Example)));

  RDB_RIEGL_DEVICE_GEOMETRY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Name)));
  RDB_RIEGL_DEVICE_GEOMETRY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Title)));
  RDB_RIEGL_DEVICE_GEOMETRY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Description)));
  RDB_RIEGL_DEVICE_GEOMETRY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Schema)));
  RDB_RIEGL_DEVICE_GEOMETRY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Example)));

  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Name)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Title)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Description)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Schema)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Example)));

  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Name)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Title)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Description)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Schema)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Example)));

  RDB_RIEGL_ECHO_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Name)));
  RDB_RIEGL_ECHO_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Title)));
  RDB_RIEGL_ECHO_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Description)));
  RDB_RIEGL_ECHO_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Schema)));
  RDB_RIEGL_ECHO_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Example)));

  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Name)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Title)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Description)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Schema)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Example)));

  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Name)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Title)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Description)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Schema)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Example)));

  RDB_RIEGL_GEO_TAG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Name)));
  RDB_RIEGL_GEO_TAG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Title)));
  RDB_RIEGL_GEO_TAG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Description)));
  RDB_RIEGL_GEO_TAG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Schema)));
  RDB_RIEGL_GEO_TAG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Example)));

  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Name)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Title)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Description)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Schema)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Example)));

  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Name)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Title)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Description)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Schema)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Example)));

  RDB_RIEGL_LICENSES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Name)));
  RDB_RIEGL_LICENSES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Title)));
  RDB_RIEGL_LICENSES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Description)));
  RDB_RIEGL_LICENSES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Schema)));
  RDB_RIEGL_LICENSES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Example)));

  RDB_RIEGL_MTA_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Name)));
  RDB_RIEGL_MTA_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Title)));
  RDB_RIEGL_MTA_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Description)));
  RDB_RIEGL_MTA_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Schema)));
  RDB_RIEGL_MTA_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Example)));

  RDB_RIEGL_NEAR_RANGE_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Name)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Title)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Description)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Schema)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Example)));

  RDB_RIEGL_NOISE_ESTIMATES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Name)));
  RDB_RIEGL_NOISE_ESTIMATES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Title)));
  RDB_RIEGL_NOISE_ESTIMATES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Description)));
  RDB_RIEGL_NOISE_ESTIMATES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Schema)));
  RDB_RIEGL_NOISE_ESTIMATES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Example)));

  RDB_RIEGL_NOTCH_FILTER.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Name)));
  RDB_RIEGL_NOTCH_FILTER.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Title)));
  RDB_RIEGL_NOTCH_FILTER.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Description)));
  RDB_RIEGL_NOTCH_FILTER.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Schema)));
  RDB_RIEGL_NOTCH_FILTER.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Example)));

  RDB_RIEGL_PIXEL_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Name)));
  RDB_RIEGL_PIXEL_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Title)));
  RDB_RIEGL_PIXEL_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Description)));
  RDB_RIEGL_PIXEL_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Schema)));
  RDB_RIEGL_PIXEL_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Example)));

  RDB_RIEGL_PLANE_PATCH_MATCHING.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Name)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Title)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Description)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Schema)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Example)));

  RDB_RIEGL_PLANE_PATCH_STATISTICS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Name)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Title)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Description)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Schema)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Example)));

  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Name)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Title)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Description)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Schema)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Example)));

  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Name)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Title)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Description)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Schema)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Example)));

  RDB_RIEGL_POINTCLOUD_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Name)));
  RDB_RIEGL_POINTCLOUD_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Title)));
  RDB_RIEGL_POINTCLOUD_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Description)));
  RDB_RIEGL_POINTCLOUD_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Schema)));
  RDB_RIEGL_POINTCLOUD_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Example)));

  RDB_RIEGL_POSE_ESTIMATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Name)));
  RDB_RIEGL_POSE_ESTIMATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Title)));
  RDB_RIEGL_POSE_ESTIMATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Description)));
  RDB_RIEGL_POSE_ESTIMATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Schema)));
  RDB_RIEGL_POSE_ESTIMATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Example)));

  RDB_RIEGL_POSE_SENSORS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Name)));
  RDB_RIEGL_POSE_SENSORS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Title)));
  RDB_RIEGL_POSE_SENSORS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Description)));
  RDB_RIEGL_POSE_SENSORS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Schema)));
  RDB_RIEGL_POSE_SENSORS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Example)));

  RDB_RIEGL_PULSE_POSITION_MODULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Name)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Title)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Description)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Schema)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Example)));

  RDB_RIEGL_RANGE_STATISTICS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Name)));
  RDB_RIEGL_RANGE_STATISTICS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Title)));
  RDB_RIEGL_RANGE_STATISTICS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Description)));
  RDB_RIEGL_RANGE_STATISTICS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Schema)));
  RDB_RIEGL_RANGE_STATISTICS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Example)));

  RDB_RIEGL_RECEIVER_INTERNALS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Name)));
  RDB_RIEGL_RECEIVER_INTERNALS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Title)));
  RDB_RIEGL_RECEIVER_INTERNALS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Description)));
  RDB_RIEGL_RECEIVER_INTERNALS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Schema)));
  RDB_RIEGL_RECEIVER_INTERNALS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Example)));

  RDB_RIEGL_RECORD_NAMES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECORD_NAMES.Name)));
  RDB_RIEGL_RECORD_NAMES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECORD_NAMES.Title)));
  RDB_RIEGL_RECORD_NAMES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECORD_NAMES.Description)));
  RDB_RIEGL_RECORD_NAMES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECORD_NAMES.Schema)));
  RDB_RIEGL_RECORD_NAMES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECORD_NAMES.Example)));

  RDB_RIEGL_REFLECTANCE_CALCULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Name)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Title)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Description)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Schema)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Example)));

  RDB_RIEGL_REFLECTANCE_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Name)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Title)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Description)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Schema)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Example)));

  RDB_RIEGL_SCAN_PATTERN.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Name)));
  RDB_RIEGL_SCAN_PATTERN.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Title)));
  RDB_RIEGL_SCAN_PATTERN.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Description)));
  RDB_RIEGL_SCAN_PATTERN.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Schema)));
  RDB_RIEGL_SCAN_PATTERN.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Example)));

  RDB_RIEGL_SHOT_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Name)));
  RDB_RIEGL_SHOT_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Title)));
  RDB_RIEGL_SHOT_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Description)));
  RDB_RIEGL_SHOT_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Schema)));
  RDB_RIEGL_SHOT_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Example)));

  RDB_RIEGL_TEMPERATURE_CALCULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Name)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Title)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Description)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Schema)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Example)));

  RDB_RIEGL_TIME_BASE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Name)));
  RDB_RIEGL_TIME_BASE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Title)));
  RDB_RIEGL_TIME_BASE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Description)));
  RDB_RIEGL_TIME_BASE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Schema)));
  RDB_RIEGL_TIME_BASE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Example)));

  RDB_RIEGL_TRAJECTORY_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Name)));
  RDB_RIEGL_TRAJECTORY_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Title)));
  RDB_RIEGL_TRAJECTORY_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Description)));
  RDB_RIEGL_TRAJECTORY_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Schema)));
  RDB_RIEGL_TRAJECTORY_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Example)));

  RDB_RIEGL_VERTEX_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Name)));
  RDB_RIEGL_VERTEX_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Title)));
  RDB_RIEGL_VERTEX_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Description)));
  RDB_RIEGL_VERTEX_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Schema)));
  RDB_RIEGL_VERTEX_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Example)));

  RDB_RIEGL_VOXEL_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Name)));
  RDB_RIEGL_VOXEL_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Title)));
  RDB_RIEGL_VOXEL_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Description)));
  RDB_RIEGL_VOXEL_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Schema)));
  RDB_RIEGL_VOXEL_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Example)));

  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Name)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Title)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Description)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Schema)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Example)));

  RDB_RIEGL_WAVEFORM_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Name)));
  RDB_RIEGL_WAVEFORM_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Title)));
  RDB_RIEGL_WAVEFORM_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Description)));
  RDB_RIEGL_WAVEFORM_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Schema)));
  RDB_RIEGL_WAVEFORM_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Example)));

  RDB_RIEGL_WAVEFORM_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Name)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Title)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Description)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Schema)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Example)));

  RDB_RIEGL_WINDOW_ANALYSIS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Name)));
  RDB_RIEGL_WINDOW_ANALYSIS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Title)));
  RDB_RIEGL_WINDOW_ANALYSIS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Description)));
  RDB_RIEGL_WINDOW_ANALYSIS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Schema)));
  RDB_RIEGL_WINDOW_ANALYSIS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Example)));

  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Name)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Title)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Description)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Schema)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Example)));
end;

procedure FillMetadataArray;
var
  i : Integer;
begin
  SetLength(RDB_META_DATA_ITEMS, 47); i := -1;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ANGULAR_NOTCH_FILTER;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ATMOSPHERE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_BEAM_GEOMETRY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_CONTROL_OBJECT_CATALOG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DETECTION_PROBABILITY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_GEOMETRY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_OUTPUT_LIMITS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ECHO_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_EXPONENTIAL_DECOMPOSITION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GAUSSIAN_DECOMPOSITION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEO_TAG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEOMETRIC_SCALE_FACTOR;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEOREFERENCING_PARAMETERS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_LICENSES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_MTA_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NEAR_RANGE_CORRECTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NOISE_ESTIMATES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NOTCH_FILTER;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PIXEL_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_PATCH_MATCHING;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_PATCH_STATISTICS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_SLOPE_CLASS_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POINT_ATTRIBUTE_GROUPS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POINTCLOUD_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POSE_ESTIMATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POSE_SENSORS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PULSE_POSITION_MODULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_RANGE_STATISTICS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_RECEIVER_INTERNALS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_RECORD_NAMES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_REFLECTANCE_CALCULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_REFLECTANCE_CORRECTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SCAN_PATTERN;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SHOT_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TEMPERATURE_CALCULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TIME_BASE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TRAJECTORY_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_VERTEX_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_VOXEL_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WINDOW_ANALYSIS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WINDOW_ECHO_CORRECTION;
end;

initialization

FixStringEncoding;
FillMetadataArray;

end.
